searchData={"items":[{"type":"module","title":"LiveViewNative","doc":"This module should be used for creating new LiveView Native Clients.","ref":"LiveViewNative.html"},{"type":"module","title":"Configuration - LiveViewNative","doc":"To use LiveView Native you must configure application\nto register LiveView Native plugins and instruct\nPhoenix on how to handle certain formats.\n\n    # registers each plugin for use\n    config :live_view_native, plugins: [\n      LiveViewNative.SwiftUI,\n      LiveViewNative.Jetpack\n    ]\n\n    # configure the mimetype for each plugin's format\n    # refer to the plugin's documentation for each format\n    # in nearly all cases the content-type should be `\"text/:format\"`\n    config :mime, :types, %{\n      \"text/swiftui\" => [:swiftui],\n      \"text/jetpack\" => [:jetpack]\n    }\n\n    # configures the stylesheet for each format\n    # refer to the documentation of `LiveViewNative.Stylesheet`\n    # for more information on configuration options\n    config :live_view_native_stylesheet,\n      content: [\n        swiftui: [\n          \"lib/**/*swiftui*\"\n        ],\n        jetpack: [\n          \"lib/**/*jetpack*\"\n        ]\n      ]\n\n    # instructs Phoenix on how to encode a given format\n    config :phoenix_template, :format_encoders, [\n      swiftui: Phoenix.HTML.Engine,\n      jetpack: Phoenix.HTML.Engine\n    ]\n\n    # instructs Phoenix on which engine to\n    # use when compiling `neex` templates\n    config :phoenix, :template_engines,\n      neex: LiveViewNative.Engine\n\nNext you should add `LiveViewNative.LiveReloader` to your application's endpoint.\n\n    if code_reloading? do\n      socket \"/phoenix/live_reload/socket\", Phoenix.LiveReloader.Socket\n      plug Phoenix.LiveReloader\n\n      # add here to ensure it is only enabled\n      # when your application is configured for code reloading\n      plug LiveViewNative.LiveReloader\n\nFinally you will need to configure your router's plugs\n\n    plug :accepts, [\"html\", \"swiftui\", \"jetpack\"]\n    plug :put_root_layout,\n      html: {MyAppWeb.Layouts, :root},\n      swiftui: {MyAppWeb.Layouts.SwiftUI, :root},\n      jetpack: {MyAppWeb.Layouts.Jetpack, :root}\n\nRefer to the documentation in `LiveViewNative.Component` for more\ninformation on native layouts.\n\nYou are now ready to create your first LiveView Native app. Refer to\nthe documentation in `LiveViewNative.LiveView` on how to configure\nyour live views for native.","ref":"LiveViewNative.html#module-configuration"},{"type":"module","title":"Enabling LiveView for Native - LiveViewNative","doc":"Now that your application is configured you will need to enable a LiveView for Native.\n\nAssuming your application has the following LiveView route:\n\n    live \"/\", HomeLive\n\nYou'll need to add `use MyAppNative, :live_view` to that module:\n\n    defmodule MyAppWeb.HomeLive do\n      use MyAppWeb, :live_view\n      use MyAppNative, :live_view\n\nNext you should use the `mix lvn.gen.live` task to generate\nthe LiveView Native render component and template.\n\n    > mix lvn.gen.live swiftui Home\n\nThis will generate the following files in your project:\n\n  * lib/my_app_web/live/home_live.swiftui.ex\n  * lib/my_app_web/live/swiftui/home_live.swiftui.neex\n\nJust like a regular LiveView you can decide not to use the template and render\ntemplates in-line inside the render component:\n\n    defmodule MyAppWeb.HomeLive.SwiftUI do\n      use MyAppNative, [:render_component, format: :swiftui]\n\n      def render(assigns, _interface) do\n        ~LVN\"\"\"\n         Hello, LiveView Native! \n        \"\"\"\n      end\n    end\n\nNote that unlike a regular LiveView that has `render/1` the\nLiveView Native render component uses `render/2` as the 2nd argument\nwill include interface information about the client.\n\nYou can read more in `LiveViewNative.Component`","ref":"LiveViewNative.html#module-enabling-liveview-for-native"},{"type":"macro","title":"LiveViewNative.__using__/1","doc":"Uses LiveViewNative for creating new clients\n\n    defmodule GameBoy do\n      use LiveViewNative,\n        format: :gameboy,\n        component: GameBoy.Component,\n        module_suffix: GameBoy,\n        template_engine: LiveViewNative.Engine,\n        client: GameBoy.Client\n    end","ref":"LiveViewNative.html#__using__/1"},{"type":"macro","title":"Options - LiveViewNative.__using__/1","doc":"* `:format` - the format that will be used by Phoenix to determine the request\n  and response encoding. Should be all lowercase and underscored\n  * `:component` - module name of the client's component module to be used within\n  render components\n  * `:module_suffix` - the module name that will be assumed to be appended to\n  liveviews for render components (i.e. MyAppWeb.HomeLive.GameBoy)\n  * `:template_engine` - the engine for compiling a client's template. In nearly\n  all cases `LiveViewNative.Engine` will be sufficient","ref":"LiveViewNative.html#__using__/1-options"},{"type":"function","title":"LiveViewNative.available_formats/0","doc":"Returns a list of all available formats\n\nThe format list is derived from the plugins returned by `LiveViewNative.plugins/0`","ref":"LiveViewNative.html#available_formats/0"},{"type":"function","title":"LiveViewNative.fetch_plugin/1","doc":"Fetches a plugin based upon the format name\n\nFollows the same return types as `Map.fetch/2`","ref":"LiveViewNative.html#fetch_plugin/1"},{"type":"function","title":"LiveViewNative.fetch_plugin!/1","doc":"Fetches a plugin based upon the format name\n\nIf the format is not present `LiveViewNative.PluginError` is raised","ref":"LiveViewNative.html#fetch_plugin!/1"},{"type":"function","title":"LiveViewNative.plugins/0","doc":"Returns a list of all available LiveView Native plugins\n\nOnly the plugins that have been registered in your application\nconfig will be returned in the list","ref":"LiveViewNative.html#plugins/0"},{"type":"module","title":"LiveViewNative.Component","doc":"Define reusable LiveView Native function components with NEEx templates.\n\nThis module is used for the following\n\n* format specific render components\n* format specific functional components\n* format specific layouts\n\nLiveView Native Components differ from Phoenix Components in that they make\nuse of a two-argument function instead of a single argument function. For example,\nwith a Phoenix Component that has a template named `foo_bar.html.heex` it would define\n`foo_bar/1` as the rendering function for that template when embeded. LiveView Native Components\nwould definee `foo_bar/2` for `foo_bar.swiftui.neex` with the 1st argument still being `assigns` and\nthe 2nd argument being `interface` map with information about the native client that is connecting.\n\nFor more information on template embedding see `LiveViewNative.Renderer.embed_templates/2`","ref":"LiveViewNative.Component.html"},{"type":"module","title":"Interface map - LiveViewNative.Component","doc":"Each native client can optionally send along an interface map that has at least the following information:\n\n  * `\"target\"` - the target device within the platform family. For example, `ios`, `ipados`, `watchos` are all targets\n  for the SwiftUI platform. Each client library should have information on the valid targets\n  * `\"version\"` - the version of your application. This is a value that you can control and pattern match on. The `version`\n  will need to be set in the native client build.\n  * `\"client_version\"` - the version of the client library that is connecting. The client will set this.","ref":"LiveViewNative.Component.html#module-interface-map"},{"type":"macro","title":"LiveViewNative.Component.__using__/1","doc":"Uses LiveView Native Component in the current module","ref":"LiveViewNative.Component.html#__using__/1"},{"type":"macro","title":"Options - LiveViewNative.Component.__using__/1","doc":"* `:format` - the format that corresponds to a LiveView Native client format for this component\n  * `:root` - the directory relative to the component module's location where templates are stored.\n  See `LiveViewNative.Renderer.embed_templates/2` for more information.\n  * `:as` - will override the name of the rendering function injected into the module.\n  See `LiveViewNative.Renderer.embed_templates/2` for more information.","ref":"LiveViewNative.Component.html#__using__/1-options"},{"type":"macro","title":"Format-Specific Render Component - LiveViewNative.Component.__using__/1","doc":"defmodule MyAppWeb.HomeLive.SwiftUI do\n      use LiveViewNative.Component,\n        format: :swiftui,\n        as: :render\n    end\n\nIn this example `:as` is used and this will inject following:\n\n    embed_templates(\"swiftui/home_live*\", root: nil, name: :render)\n\nAssuming there is a `swiftui/home_live.swiftui.neex` this will be embeded in the render\ncomponent as `render/2`.\n\nAlternatively if you do not want to use templates but the in-line rendering you can declare your own\n`render/2` functions\n\n    def render(assigns, %{\"target\" => \"watchos\"}) do\n      ~LVN\"\"\"\n       Hello, from WatchOS! \n      \"\"\"\n    end\n\n    def render(assigns, %{\"target\" => target}) when target in ~w{macos tvos} do\n      ~LVN\"\"\"\n       Hello, from <%= target %>! \n      \"\"\"\n    end\n\n    def render(assigns, _interface) do\n      ~LVN\"\"\"\n       Hello, from SwiftUI! \n      \"\"\"\n    end","ref":"LiveViewNative.Component.html#__using__/1-format-specific-render-component"},{"type":"macro","title":"Format-Specific Function Component - LiveViewNative.Component.__using__/1","doc":"defmodule MyAppWeb.NativeComponent.SwiftUI do\n      use LiveViewNative.Component,\n        format: :swiftui\n    end\n\nWhen using to write your own function components it is nearly identical to `Phoenix.Component`.\nYou will use `embed_templates/2` for template embedding and this will inject functions that take\n`assigns` and `interface` as arguments.\n\nYou can also define your own functions but you lose the 2 arity, or you can create it yourself.\n\n    def radio_button(assigns) do\n      interface = LiveViewNative.Utils.get_interface(assigns)\n      radio_button(assign, interface)\n    end\n\n    def radio_button(assigns, %{\"target\" => \"watchos\"}) do\n      ~LVN\"\"\"\n        ...\n      \"\"\"\n    end","ref":"LiveViewNative.Component.html#__using__/1-format-specific-function-component"},{"type":"macro","title":"Format-Specific Layouts - LiveViewNative.Component.__using__/1","doc":"defmodule MyAppWeb.Layouts.SwiftUI do\n      use LiveViewNative.Component,\n        format: :swiftui\n\n      import LiveViewNative.Component, only: [csrf_token: 2]\n\n      embed_templates \"layouts_swiftui/*\"\n    end\n\nMost times you will want to provide `app` and `root` templates.\nFor stylesheet embedding refer to `LiveViewNative.Stylesheet.Component`","ref":"LiveViewNative.Component.html#__using__/1-format-specific-layouts"},{"type":"function","title":"LiveViewNative.Component.async_result/2","doc":"Please see the documentation for Phoenix.Component.async_result/1","ref":"LiveViewNative.Component.html#async_result/2"},{"type":"function","title":"Attributes - LiveViewNative.Component.async_result/2","doc":"* `assign` (`Phoenix.LiveView.AsyncResult`) (required)","ref":"LiveViewNative.Component.html#async_result/2-attributes"},{"type":"function","title":"Slots - LiveViewNative.Component.async_result/2","doc":"* `loading` - rendered while the assign is loading for the first time.\n* `failed` - rendered when an error or exit is caught or assign_async returns `{:error, reason}` for the first time. Receives the error as a `:let`.\n* `inner_block` - rendered when the assign is loaded successfully via `AsyncResult.ok/2`. Receives the result as a `:let`.","ref":"LiveViewNative.Component.html#async_result/2-slots"},{"type":"function","title":"LiveViewNative.Component.csrf_token/2","doc":"Embed the CSRF token for LiveView as a tag","ref":"LiveViewNative.Component.html#csrf_token/2"},{"type":"function","title":"LiveViewNative.Component.live_component/2","doc":"","ref":"LiveViewNative.Component.html#live_component/2"},{"type":"macro","title":"LiveViewNative.Component.sigil_LVN/2","doc":"The `~LVN` sigil for writing HEEx templates inside source files.\n\nUsing `~LVN` is nearly identical to `~H` in `Phoenix.Component` but deviates\nin various ways.\n\nOne common misconception is that LiveView Native templates are just HTML or XML. This is not true.\nBoth HTML and XML have specifications that at times conflict with the needs of how LiveView Native client\nUI frameworks should be represented. Think of LiveView Native templates as a composable markup whose specification\nis currently under development. As we continue to expand the LiveView Native ecosystem this list will likely grow:\n\n  * casing - `~LVN` does not enforce downcasing of tag names so ` ` is a valid tag name","ref":"LiveViewNative.Component.html#sigil_LVN/2"},{"type":"macro","title":"Special attributes - LiveViewNative.Component.sigil_LVN/2","doc":"LVN tempalates support all of the [HEEx special attributes](https://hexdocs.pm/phoenix_live_view/Phoenix.Component.html#sigil_H/2-special-attributes)\nin addition to LVN-specific special attributes:\n\n#### :interface-\n\nThe `:interface-` atrribute allows you to match against a given `interface` value from the client. Similar to `data-` in HTML the name that is appended\nis the key within the deeply nested value to match against. For example `:interface-target`:\n\n```heex\n This is a phone \n This is a watch \n```\n\nThe elements will conditionally render based upon a matching `interface[\"target\"]` value. Internally this is converted to `:if`:\n\n```heex\n This is a phone \n This is a watch \n```\n\nThis convenience is intended for UI where one-off changes are necessary for specific cases to avoid having to define an entirely new template.","ref":"LiveViewNative.Component.html#sigil_LVN/2-special-attributes"},{"type":"module","title":"LiveViewNative.ContentNegotiator","doc":"The callback module for delegating LiveView Native format\nrequests to the correct render component","ref":"LiveViewNative.ContentNegotiator.html"},{"type":"module","title":"LiveViewNative.Engine","doc":"The LiveViewNative.Engine that powers `.neex` templates and the `~LVN` sigil.\n\nIt works by adding a LiveView Native template parsing and validation layer on top\nof `Phoenix.LiveView.TagEngine`.","ref":"LiveViewNative.Engine.html"},{"type":"function","title":"LiveViewNative.Engine.encode_to_iodata!/1","doc":"Encodes the HTML templates to iodata.","ref":"LiveViewNative.Engine.html#encode_to_iodata!/1"},{"type":"module","title":"LiveViewNative.LVN","doc":"Provides commands for executing Native utility operations on the client.\n\nLVN commands support a variety of utility operations for common client-side\nneeds, such as adding or removing CSS classes, setting or removing tag attributes,\nshowing or hiding content, and transitioning in and out with animations.\nWhile these operations can be accomplished via client-side hooks,\nLVN commands are ViewTree-patch aware, so operations applied\nby the LVN APIs will stick to elements across patches from the server.\n\nIn addition to purely client-side utilities, the LVN commands include a\nrich `push` API, for extending the default `phx-` binding pushes with\noptions to customize targets, loading states, and additional payload values.","ref":"LiveViewNative.LVN.html"},{"type":"module","title":"Client Utility Commands - LiveViewNative.LVN","doc":"The following utilities are included:\n\n  * `add_class` - Add classes to elements, with optional transitions\n  * `remove_class` - Remove classes from elements, with optional transitions\n  * `toggle_class` - Sets or removes classes from elements, with optional transitions\n  * `set_attribute` - Set an attribute on elements\n  * `remove_attribute` - Remove an attribute from elements\n  * `toggle_attribute` - Sets or removes element attribute based on attribute presence.\n  * `show` - Show elements, with optional transitions\n  * `hide` - Hide elements, with optional transitions\n  * `toggle` - Shows or hides elements based on visibility, with optional transitions\n  * `transition` - Apply a temporary transition to elements for animations\n  * `dispatch` - Dispatch a ViewTree event to elements\n\nFor example, the following modal component can be shown or hidden on the\nclient without a trip to the server:\n\n    alias LiveViewNative.LVN\n\n    def hide_modal(lvn \\\\ %LVN{}) do\n      lvn\n      |> LVN.hide(transition: \"fade-out\", to: \"#modal\")\n      |> LVN.hide(transition: \"fade-out-scale\", to: \"#modal-content\")\n    end\n\n    def modal(assigns) do\n      ~LVN\"\"\"\n       \n         \n           ✖ \n           {@text} \n         \n       \n      \"\"\"\n    end","ref":"LiveViewNative.LVN.html#module-client-utility-commands"},{"type":"module","title":"Enhanced push events - LiveViewNative.LVN","doc":"The `push/1` command allows you to extend the built-in pushed event handling\nwhen a `phx-` event is pushed to the server. For example, you may wish to\ntarget a specific component, specify additional payload values to include\nwith the event, apply loading states to external elements, etc. For example,\ngiven this basic `phx-click` event:\n\n```heex\n + \n```\n\nImagine you need to target your current component, and apply a loading state\nto the parent container while the client awaits the server acknowledgement:\n\n    alias LiveViewNative.LVN\n\n    ~LVN\"\"\"\n     + \n    \"\"\"\n\nPush commands also compose with all other utilities. For example,\nto add a class when pushing:\n\n```heex\n  LVN.add_class(\"warmer\", to: \".thermo\")\n}>+ \n```\n\nAny `phx-value-*` attributes will also be included in the payload, their\nvalues will be overwritten by values given directly to `push/1`. Any\n`phx-target` attribute will also be used, and overwritten.\n\n```heex\n + \n```","ref":"LiveViewNative.LVN.html#module-enhanced-push-events"},{"type":"module","title":"Custom LVN events with `LVN.dispatch/1` and `window.addEventListener` - LiveViewNative.LVN","doc":"`dispatch/1` can be used to dispatch custom Native events to\nelements. For example, you can use `LVN.dispatch(\"click\", to: \"#foo\")`,\nto dispatch a click event to an element.\n\nThis also means you can augment your elements with custom events,\nby using Native's `window.addEventListener` and invoking them\nwith `dispatch/1`. For example, imagine you want to provide\na copy-to-clipboard functionality in your application. You can\nadd a custom event for it:\n\n# TODO replace with native version\n    window.addEventListener(\"my_app:clipcopy\", (event) => {\n      if (\"clipboard\" in navigator) {\n        const text = event.target.textContent;\n        navigator.clipboard.writeText(text);\n      } else {\n        alert(\"Sorry, your browser does not support clipboard copy.\");\n      }\n    });\n\nNow you can have a Button like this:\n\n```heex\n \n  Copy content\n \n```\n\nThe combination of `dispatch/1` with `window.addEventListener` is\na powerful mechanism to increase the amount of actions you can trigger\nclient-side from your LiveView code.","ref":"LiveViewNative.LVN.html#module-custom-lvn-events-with-lvn-dispatch-1-and-window-addeventlistener"},{"type":"function","title":"LiveViewNative.LVN.add_class/1","doc":"Adds classes to elements.\n\n  * `names` - A string with one or more class names to add.","ref":"LiveViewNative.LVN.html#add_class/1"},{"type":"function","title":"Options - LiveViewNative.LVN.add_class/1","doc":"* `:to` - An optional ViewTree selector to add classes to.\n    Defaults to the interacted element.\n  * `:transition` - A string of classes to apply before adding classes or\n    a 3-tuple containing the transition class, the class to apply\n    to start the transition, and the ending transition class, such as:\n    `{\"ease-out duration-300\", \"opacity-0\", \"opacity-100\"}`\n  * `:time` - The time in milliseconds to apply the transition from `:transition`.\n    Defaults to 200.","ref":"LiveViewNative.LVN.html#add_class/1-options"},{"type":"function","title":"Examples - LiveViewNative.LVN.add_class/1","doc":"My Item \n     \n      highlight!","ref":"LiveViewNative.LVN.html#add_class/1-examples"},{"type":"function","title":"LiveViewNative.LVN.add_class/2","doc":"See `add_class/1`.","ref":"LiveViewNative.LVN.html#add_class/2"},{"type":"function","title":"LiveViewNative.LVN.add_class/3","doc":"See `add_class/1`.","ref":"LiveViewNative.LVN.html#add_class/3"},{"type":"function","title":"LiveViewNative.LVN.concat/2","doc":"Combines two JS commands, appending the second to the first.","ref":"LiveViewNative.LVN.html#concat/2"},{"type":"function","title":"LiveViewNative.LVN.dispatch/2","doc":"Dispatches an event to the ViewTree.\n\n  * `event` - The string event name to dispatch.\n\n*Note*: All events dispatched are of a type\n[CustomEvent](https://developer.mozilla.org/en-US/docs/Web/API/CustomEvent),\nwith the exception of `\"click\"`. For a `\"click\"`, a\n[MouseEvent](https://developer.mozilla.org/en-US/docs/Web/API/MouseEvent)\nis dispatched to properly simulate a UI click.\n\nFor emitted `CustomEvent`'s, the event detail will contain a `dispatcher`,\nwhich references the ViewTree node that dispatched the LVN event to the target\nelement.","ref":"LiveViewNative.LVN.html#dispatch/2"},{"type":"function","title":"Options - LiveViewNative.LVN.dispatch/2","doc":"* `:to` - An optional ViewTree selector to dispatch the event to.\n    Defaults to the interacted element.\n  * `:detail` - An optional detail map to dispatch along\n    with the client event. The details will be available in the\n    `event.detail` attribute for event listeners.\n  * `:bubbles` – A boolean flag to bubble the event or not. Defaults to `true`.","ref":"LiveViewNative.LVN.html#dispatch/2-options"},{"type":"function","title":"Examples - LiveViewNative.LVN.dispatch/2","doc":"# TODO: replace with native example\n    window.addEventListener(\"click\", e => console.log(\"clicked!\", e.detail))\n\n     Click me!","ref":"LiveViewNative.LVN.html#dispatch/2-examples"},{"type":"function","title":"LiveViewNative.LVN.dispatch/3","doc":"See `dispatch/2`.","ref":"LiveViewNative.LVN.html#dispatch/3"},{"type":"function","title":"LiveViewNative.LVN.exec/1","doc":"Executes LVN commands located in an element's attribute.\n\n  * `attr` - The string attribute where the LVN command is specified","ref":"LiveViewNative.LVN.html#exec/1"},{"type":"function","title":"Options - LiveViewNative.LVN.exec/1","doc":"* `:to` - An optional ViewTree selector to fetch the attribute from.\n    Defaults to the current element.","ref":"LiveViewNative.LVN.html#exec/1-options"},{"type":"function","title":"Examples - LiveViewNative.LVN.exec/1","doc":"... \n     close","ref":"LiveViewNative.LVN.html#exec/1-examples"},{"type":"function","title":"LiveViewNative.LVN.exec/2","doc":"See `exec/1`.","ref":"LiveViewNative.LVN.html#exec/2"},{"type":"function","title":"LiveViewNative.LVN.exec/3","doc":"See `exec/1`.","ref":"LiveViewNative.LVN.html#exec/3"},{"type":"function","title":"LiveViewNative.LVN.focus/1","doc":"Sends focus to a selector.","ref":"LiveViewNative.LVN.html#focus/1"},{"type":"function","title":"Options - LiveViewNative.LVN.focus/1","doc":"* `:to` - An optional ViewTree selector to send focus to.\n    Defaults to the current element.","ref":"LiveViewNative.LVN.html#focus/1-options"},{"type":"function","title":"Examples - LiveViewNative.LVN.focus/1","doc":"LVN.focus(to: \"main\")","ref":"LiveViewNative.LVN.html#focus/1-examples"},{"type":"function","title":"LiveViewNative.LVN.focus/2","doc":"See `focus/1`.","ref":"LiveViewNative.LVN.html#focus/2"},{"type":"function","title":"LiveViewNative.LVN.focus_first/1","doc":"Sends focus to the first focusable child in selector.","ref":"LiveViewNative.LVN.html#focus_first/1"},{"type":"function","title":"Options - LiveViewNative.LVN.focus_first/1","doc":"* `:to` - An optional ViewTree selector to focus.\n    Defaults to the current element.","ref":"LiveViewNative.LVN.html#focus_first/1-options"},{"type":"function","title":"Examples - LiveViewNative.LVN.focus_first/1","doc":"LVN.focus_first(to: \"#modal\")","ref":"LiveViewNative.LVN.html#focus_first/1-examples"},{"type":"function","title":"LiveViewNative.LVN.focus_first/2","doc":"See `focus_first/1`.","ref":"LiveViewNative.LVN.html#focus_first/2"},{"type":"function","title":"LiveViewNative.LVN.hide/1","doc":"Hides elements.","ref":"LiveViewNative.LVN.html#hide/1"},{"type":"function","title":"Options - LiveViewNative.LVN.hide/1","doc":"* `:to` - An optional ViewTree selector to hide.\n    Defaults to the interacted element.\n  * `:transition` - A string of classes to apply before hiding or\n    a 3-tuple containing the transition class, the class to apply\n    to start the transition, and the ending transition class, such as:\n    `{\"ease-out duration-300\", \"opacity-100\", \"opacity-0\"}`\n  * `:time` - The time in milliseconds to apply the transition from `:transition`.\n    Defaults to 200.\n\nDuring the process, the following events will be dispatched to the hidden elements:\n\n  * When the action is triggered on the client, `phx:hide-start` is dispatched.\n  * After the time specified by `:time`, `phx:hide-end` is dispatched.","ref":"LiveViewNative.LVN.html#hide/1-options"},{"type":"function","title":"Examples - LiveViewNative.LVN.hide/1","doc":"My Item \n\n     \n      hide!\n     \n\n     \n      hide fancy!","ref":"LiveViewNative.LVN.html#hide/1-examples"},{"type":"function","title":"LiveViewNative.LVN.hide/2","doc":"See `hide/1`.","ref":"LiveViewNative.LVN.html#hide/2"},{"type":"function","title":"LiveViewNative.LVN.navigate/1","doc":"Sends a navigation event to the server and updates the browser's pushState history.","ref":"LiveViewNative.LVN.html#navigate/1"},{"type":"function","title":"Options - LiveViewNative.LVN.navigate/1","doc":"* `:replace` - Whether to replace the browser's pushState history. Defaults to `false`.","ref":"LiveViewNative.LVN.html#navigate/1-options"},{"type":"function","title":"Examples - LiveViewNative.LVN.navigate/1","doc":"LVN.navigate(\"/my-path\")","ref":"LiveViewNative.LVN.html#navigate/1-examples"},{"type":"function","title":"LiveViewNative.LVN.navigate/2","doc":"See `navigate/1`.","ref":"LiveViewNative.LVN.html#navigate/2"},{"type":"function","title":"LiveViewNative.LVN.navigate/3","doc":"See `navigate/1`.","ref":"LiveViewNative.LVN.html#navigate/3"},{"type":"function","title":"LiveViewNative.LVN.patch/1","doc":"Sends a patch event to the server and updates the browser's pushState history.","ref":"LiveViewNative.LVN.html#patch/1"},{"type":"function","title":"Options - LiveViewNative.LVN.patch/1","doc":"* `:replace` - Whether to replace the browser's pushState history. Defaults to `false`.","ref":"LiveViewNative.LVN.html#patch/1-options"},{"type":"function","title":"Examples - LiveViewNative.LVN.patch/1","doc":"LVN.patch(\"/my-path\")","ref":"LiveViewNative.LVN.html#patch/1-examples"},{"type":"function","title":"LiveViewNative.LVN.patch/2","doc":"See `patch/1`.","ref":"LiveViewNative.LVN.html#patch/2"},{"type":"function","title":"LiveViewNative.LVN.patch/3","doc":"See `patch/1`.","ref":"LiveViewNative.LVN.html#patch/3"},{"type":"function","title":"LiveViewNative.LVN.pop_focus/1","doc":"Focuses the last pushed element.","ref":"LiveViewNative.LVN.html#pop_focus/1"},{"type":"function","title":"Examples - LiveViewNative.LVN.pop_focus/1","doc":"LVN.pop_focus()","ref":"LiveViewNative.LVN.html#pop_focus/1-examples"},{"type":"function","title":"LiveViewNative.LVN.push/1","doc":"Pushes an event to the server.\n\n  * `event` - The string event name to push.","ref":"LiveViewNative.LVN.html#push/1"},{"type":"function","title":"Options - LiveViewNative.LVN.push/1","doc":"* `:target` - A selector or component ID to push to. This value will\n    overwrite any `phx-target` attribute present on the element.\n  * `:loading` - A selector to apply the phx loading classes to.\n  * `:page_loading` - Boolean to trigger the phx:page-loading-start and\n    phx:page-loading-stop events for this push. Defaults to `false`.\n  * `:value` - A map of values to send to the server. These values will be\n    merged over any `phx-value-*` attributes that are present on the element.\n    All keys will be treated as strings when merging.","ref":"LiveViewNative.LVN.html#push/1-options"},{"type":"function","title":"Examples - LiveViewNative.LVN.push/1","doc":"```heex\n click me! \n click me! \n click me! \n```","ref":"LiveViewNative.LVN.html#push/1-examples"},{"type":"function","title":"LiveViewNative.LVN.push/2","doc":"See `push/1`.","ref":"LiveViewNative.LVN.html#push/2"},{"type":"function","title":"LiveViewNative.LVN.push/3","doc":"See `push/1`.","ref":"LiveViewNative.LVN.html#push/3"},{"type":"function","title":"LiveViewNative.LVN.push_focus/1","doc":"Pushes focus from the source element to be later popped.","ref":"LiveViewNative.LVN.html#push_focus/1"},{"type":"function","title":"Options - LiveViewNative.LVN.push_focus/1","doc":"* `:to` - An optional ViewTree selector to push focus to.\n    Defaults to the current element.","ref":"LiveViewNative.LVN.html#push_focus/1-options"},{"type":"function","title":"Examples - LiveViewNative.LVN.push_focus/1","doc":"LVN.push_focus()\n    LVN.push_focus(to: \"#my-Button\")","ref":"LiveViewNative.LVN.html#push_focus/1-examples"},{"type":"function","title":"LiveViewNative.LVN.push_focus/2","doc":"See `push_focus/1`.","ref":"LiveViewNative.LVN.html#push_focus/2"},{"type":"function","title":"LiveViewNative.LVN.remove_attribute/1","doc":"Removes an attribute from elements.\n\n  * `attr` - The string attribute name to remove.","ref":"LiveViewNative.LVN.html#remove_attribute/1"},{"type":"function","title":"Options - LiveViewNative.LVN.remove_attribute/1","doc":"* `:to` - An optional ViewTree selector to remove attributes from.\n    Defaults to the interacted element.","ref":"LiveViewNative.LVN.html#remove_attribute/1-options"},{"type":"function","title":"Examples - LiveViewNative.LVN.remove_attribute/1","doc":"hide","ref":"LiveViewNative.LVN.html#remove_attribute/1-examples"},{"type":"function","title":"LiveViewNative.LVN.remove_attribute/2","doc":"See `remove_attribute/1`.","ref":"LiveViewNative.LVN.html#remove_attribute/2"},{"type":"function","title":"LiveViewNative.LVN.remove_attribute/3","doc":"See `remove_attribute/1`.","ref":"LiveViewNative.LVN.html#remove_attribute/3"},{"type":"function","title":"LiveViewNative.LVN.remove_class/1","doc":"Removes classes from elements.\n\n  * `names` - A string with one or more class names to remove.","ref":"LiveViewNative.LVN.html#remove_class/1"},{"type":"function","title":"Options - LiveViewNative.LVN.remove_class/1","doc":"* `:to` - An optional ViewTree selector to remove classes from.\n    Defaults to the interacted element.\n  * `:transition` - A string of classes to apply before removing classes or\n    a 3-tuple containing the transition class, the class to apply\n    to start the transition, and the ending transition class, such as:\n    `{\"ease-out duration-300\", \"opacity-0\", \"opacity-100\"}`\n  * `:time` - The time in milliseconds to apply the transition from `:transition`.\n    Defaults to 200.","ref":"LiveViewNative.LVN.html#remove_class/1-options"},{"type":"function","title":"Examples - LiveViewNative.LVN.remove_class/1","doc":"My Item \n     \n      remove highlight!","ref":"LiveViewNative.LVN.html#remove_class/1-examples"},{"type":"function","title":"LiveViewNative.LVN.remove_class/2","doc":"See `remove_class/1`.","ref":"LiveViewNative.LVN.html#remove_class/2"},{"type":"function","title":"LiveViewNative.LVN.remove_class/3","doc":"See `remove_class/1`.","ref":"LiveViewNative.LVN.html#remove_class/3"},{"type":"function","title":"LiveViewNative.LVN.set_attribute/1","doc":"Sets an attribute on elements.\n\nAccepts a tuple containing the string attribute name/value pair.","ref":"LiveViewNative.LVN.html#set_attribute/1"},{"type":"function","title":"Options - LiveViewNative.LVN.set_attribute/1","doc":"* `:to` - An optional ViewTree selector to add attributes to.\n    Defaults to the interacted element.","ref":"LiveViewNative.LVN.html#set_attribute/1-options"},{"type":"function","title":"Examples - LiveViewNative.LVN.set_attribute/1","doc":"show","ref":"LiveViewNative.LVN.html#set_attribute/1-examples"},{"type":"function","title":"LiveViewNative.LVN.set_attribute/2","doc":"See `set_attribute/1`.","ref":"LiveViewNative.LVN.html#set_attribute/2"},{"type":"function","title":"LiveViewNative.LVN.set_attribute/3","doc":"See `set_attribute/1`.","ref":"LiveViewNative.LVN.html#set_attribute/3"},{"type":"function","title":"LiveViewNative.LVN.show/1","doc":"Shows elements.","ref":"LiveViewNative.LVN.html#show/1"},{"type":"function","title":"Options - LiveViewNative.LVN.show/1","doc":"* `:to` - An optional ViewTree selector to show.\n    Defaults to the interacted element.\n  * `:transition` - A string of classes to apply before showing or\n    a 3-tuple containing the transition class, the class to apply\n    to start the transition, and the ending transition class, such as:\n    `{\"ease-out duration-300\", \"opacity-0\", \"opacity-100\"}`\n  * `:time` - The time in milliseconds to apply the transition from `:transition`.\n    Defaults to 200.\n  * `:display` - An optional display value to set when showing. Defaults to `\"block\"`.\n\nDuring the process, the following events will be dispatched to the shown elements:\n\n  * When the action is triggered on the client, `phx:show-start` is dispatched.\n  * After the time specified by `:time`, `phx:show-end` is dispatched.","ref":"LiveViewNative.LVN.html#show/1-options"},{"type":"function","title":"Examples - LiveViewNative.LVN.show/1","doc":"My Item \n\n     \n      show!\n     \n\n     \n      show fancy!","ref":"LiveViewNative.LVN.html#show/1-examples"},{"type":"function","title":"LiveViewNative.LVN.show/2","doc":"See `show/1`.","ref":"LiveViewNative.LVN.html#show/2"},{"type":"function","title":"LiveViewNative.LVN.toggle/1","doc":"Toggles element visibility.","ref":"LiveViewNative.LVN.html#toggle/1"},{"type":"function","title":"Options - LiveViewNative.LVN.toggle/1","doc":"* `:to` - An optional ViewTree selector to toggle.\n    Defaults to the interacted element.\n  * `:in` - A string of classes to apply when toggling in, or\n    a 3-tuple containing the transition class, the class to apply\n    to start the transition, and the ending transition class, such as:\n    `{\"ease-out duration-300\", \"opacity-0\", \"opacity-100\"}`\n  * `:out` - A string of classes to apply when toggling out, or\n    a 3-tuple containing the transition class, the class to apply\n    to start the transition, and the ending transition class, such as:\n    `{\"ease-out duration-300\", \"opacity-100\", \"opacity-0\"}`\n  * `:time` - The time in milliseconds to apply the transition `:in` and `:out` classes.\n    Defaults to 200.\n  * `:display` - An optional display value to set when toggling in. Defaults\n    to `\"block\"`.\n\nWhen the toggle is complete on the client, a `phx:show-start` or `phx:hide-start`, and\n`phx:show-end` or `phx:hide-end` event will be dispatched to the toggled elements.","ref":"LiveViewNative.LVN.html#toggle/1-options"},{"type":"function","title":"Examples - LiveViewNative.LVN.toggle/1","doc":"My Item \n\n     \n      toggle item!\n     \n\n     \n      toggle fancy!","ref":"LiveViewNative.LVN.html#toggle/1-examples"},{"type":"function","title":"LiveViewNative.LVN.toggle/2","doc":"See `toggle/1`.","ref":"LiveViewNative.LVN.html#toggle/2"},{"type":"function","title":"LiveViewNative.LVN.toggle_attribute/1","doc":"Sets or removes element attribute based on attribute presence.\n\nAccepts a two or three-element tuple:\n\n* `{attr, val}` - Sets the attribute to the given value or removes it\n* `{attr, val1, val2}` - Toggles the attribute between `val1` and `val2`","ref":"LiveViewNative.LVN.html#toggle_attribute/1"},{"type":"function","title":"Options - LiveViewNative.LVN.toggle_attribute/1","doc":"* `:to` - An optional ViewTree selector to set or remove attributes from.\n    Defaults to the interacted element.","ref":"LiveViewNative.LVN.html#toggle_attribute/1-options"},{"type":"function","title":"Examples - LiveViewNative.LVN.toggle_attribute/1","doc":"toggle\n     \n\n     \n      toggle","ref":"LiveViewNative.LVN.html#toggle_attribute/1-examples"},{"type":"function","title":"LiveViewNative.LVN.toggle_attribute/2","doc":"See `toggle_attribute/1`.","ref":"LiveViewNative.LVN.html#toggle_attribute/2"},{"type":"function","title":"LiveViewNative.LVN.toggle_attribute/3","doc":"See `toggle_attribute/1`.","ref":"LiveViewNative.LVN.html#toggle_attribute/3"},{"type":"function","title":"LiveViewNative.LVN.toggle_class/1","doc":"Adds or removes element classes based on presence.\n\n  * `names` - A string with one or more class names to toggle.","ref":"LiveViewNative.LVN.html#toggle_class/1"},{"type":"function","title":"Options - LiveViewNative.LVN.toggle_class/1","doc":"* `:to` - An optional ViewTree selector to target.\n    Defaults to the interacted element.\n  * `:transition` - A string of classes to apply before adding classes or\n    a 3-tuple containing the transition class, the class to apply\n    to start the transition, and the ending transition class, such as:\n    `{\"ease-out duration-300\", \"opacity-0\", \"opacity-100\"}`\n  * `:time` - The time in milliseconds to apply the transition from `:transition`.\n    Defaults to 200.","ref":"LiveViewNative.LVN.html#toggle_class/1-options"},{"type":"function","title":"Examples - LiveViewNative.LVN.toggle_class/1","doc":"My Item \n     \n      toggle active!","ref":"LiveViewNative.LVN.html#toggle_class/1-examples"},{"type":"function","title":"LiveViewNative.LVN.toggle_class/2","doc":"","ref":"LiveViewNative.LVN.html#toggle_class/2"},{"type":"function","title":"LiveViewNative.LVN.toggle_class/3","doc":"","ref":"LiveViewNative.LVN.html#toggle_class/3"},{"type":"function","title":"LiveViewNative.LVN.transition/1","doc":"Transitions elements.\n\n  * `transition` - A string of classes to apply before removing classes or\n    a 3-tuple containing the transition class, the class to apply\n    to start the transition, and the ending transition class, such as:\n    `{\"ease-out duration-300\", \"opacity-0\", \"opacity-100\"}`\n\nTransitions are useful for temporarily adding an animation class\nto elements, such as for highlighting content changes.","ref":"LiveViewNative.LVN.html#transition/1"},{"type":"function","title":"Options - LiveViewNative.LVN.transition/1","doc":"* `:to` - An optional ViewTree selector to apply transitions to.\n    Defaults to the interacted element.\n  * `:time` - The time in milliseconds to apply the transition from `:transition`.\n    Defaults to 200.","ref":"LiveViewNative.LVN.html#transition/1-options"},{"type":"function","title":"Examples - LiveViewNative.LVN.transition/1","doc":"My Item \n     Shake!","ref":"LiveViewNative.LVN.html#transition/1-examples"},{"type":"function","title":"LiveViewNative.LVN.transition/2","doc":"See `transition/1`.","ref":"LiveViewNative.LVN.html#transition/2"},{"type":"function","title":"LiveViewNative.LVN.transition/3","doc":"See `transition/1`.","ref":"LiveViewNative.LVN.html#transition/3"},{"type":"module","title":"LiveViewNative.LiveComponent.CID","doc":"The struct representing an internal unique reference to the component instance,\navailable as the `@myself` assign in live components.\n\nRead more about the uses of `@myself` in the `Phoenix.LiveComponent` docs.","ref":"LiveViewNative.LiveComponent.CID.html"},{"type":"module","title":"LiveViewNative.LiveReloader","doc":"Router for live-reload detection of LiveView Native applications in development.\n\n# Usage\n\nAdd the `LiveViewNative.LiveReloader` plug within a `code_reloading?` block\nin your Endpoint, ie:\n\n    if code_reloading? do\n      socket \"/phoenix/live_reload/socket\", Phoenix.LiveReloader.Socket\n      plug Phoenix.LiveReloader\n      plug LiveViewNative.LiveReloader\n    end","ref":"LiveViewNative.LiveReloader.html"},{"type":"function","title":"LiveViewNative.LiveReloader.call/2","doc":"","ref":"LiveViewNative.LiveReloader.html#call/2"},{"type":"function","title":"LiveViewNative.LiveReloader.init/1","doc":"","ref":"LiveViewNative.LiveReloader.html#init/1"},{"type":"module","title":"LiveViewNative.LiveView","doc":"Use this module within a LiveView to delegate rendering requests\nfrom a native client to a format specific rendering component.\n\nAll event handling should remain in the LiveView, all rendering\nconcerns for a given format will be delegated to the component.\n\nPlease refer to `LiveViewNative.Component` for more information\non rendering components.","ref":"LiveViewNative.LiveView.html"},{"type":"macro","title":"LiveViewNative.LiveView.__using__/1","doc":"Uses LiveView Native in the current module for rendering delegation\n\n    defmodule MyAppWeb.HomeLive do\n      use MyAppWeb, :live_view\n      use LiveViewNative.LiveView,\n        formats: [:swiftui, :jetpack],\n        layouts: [\n          swiftui: {MyAppWeb.Layouts.SwiftUI, :app},\n          jetpack: {MyAppWeb.Layouts.Jetpack, :app}\n        ],\n        dispatch_to: &Module.concat/2\n    end","ref":"LiveViewNative.LiveView.html#__using__/1"},{"type":"macro","title":"Options - LiveViewNative.LiveView.__using__/1","doc":"* `:formats` - the formats this LiveView will delegate to\n    a render component. For example, specifying `formats: [:swiftui, jetpack]`\n    for a LiveView named `MyAppWeb.HomeLive` will\n    invoke `MyAppWeb.HomeLive.SwiftUI` and `MyAppWeb.HomeLivew.Jetpack` when\n    respectively rendering each format. The appended module suffix\n    is taken from the `:module_suffix` value on each registered LiveView Native\n    plugin.\n\n  * `:layouts` - which layouts to render for each format,\n    for example: `[swiftui: {MyAppWeb.Layouts.SwiftUI, :app}]`\n\n  * `:dispatch_to` - a function that takes the parent LiveView module\n    and the format's `plugin.module_suffix` and will determine\n    which module the `render/1` function will be called on","ref":"LiveViewNative.LiveView.html#__using__/1-options"},{"type":"module","title":"LiveViewNative.Renderer","doc":"This module contains logic on how template rendering and embedding is implemented","ref":"LiveViewNative.Renderer.html"},{"type":"macro","title":"LiveViewNative.Renderer.embed_templates/2","doc":"Embeds templates as render functions\n\nThis function is mostly identical to `Phoenix.Component.embed_templates/2` but deviates in a few ways","ref":"LiveViewNative.Renderer.html#embed_templates/2"},{"type":"macro","title":"Options - LiveViewNative.Renderer.embed_templates/2","doc":"* `:format` - the format from the client. This will be used for template discovery, for the format\n  `:swiftui` templates such as `home_live.swiftui.neex` will collected.\n  * `:name` - the name of the generated function. Defaults to the name of the template, for example\n  `app.swiftui.neex` will generate `app/2`. If this value is passed in there must only be a single template\n  name matched. So if the pattern results in `['home_live.swiftui.neex', 'user_list.swiftui.neex']` and\n  you pass `name: :render` there is ambiguity and will `raise`. The exception is when there are multiple\n  targets for the same name: `['home_live.swiftui+watchos.neex', 'home_live.swiftui+tvos.neex', 'home_live.swiftui.neex']`\n  if `name: :render` this will result:\n\n    def render(assings, %{\"target\" => \"watchos\"} = interface)\n    def render(assigns, %{\"target\" => \"tvos\"} = interface)\n    def render(assigns, interface)\n\n  the fallback function will always sort to render last. This allows for a greedy matcher if more than one target\n  will be used for the same template.\n\n  * `:root` - the location from which the `pattern` is applied to for finding templates. This is relative\n  to the rendering module.","ref":"LiveViewNative.Renderer.html#embed_templates/2-options"},{"type":"module","title":"LiveViewNative.TagEngine","doc":"For more information on TagEngine please see `LiveViewNative.TagEngine`","ref":"LiveViewNative.TagEngine.html"},{"type":"function","title":"LiveViewNative.TagEngine.component/3","doc":"Renders a component defined by the given function.\n\nThis function is rarely invoked directly by users. Instead, it is used by `~H`\nand other engine implementations to render `Phoenix.Component`s. For example,\nthe following:\n\n```heex\n \n```\n\nIs the same as:\n\n```heex\n<%= component(\n      &MyApp.Weather.city/1,\n      [name: \"Kraków\"],\n      {__ENV__.module, __ENV__.function, __ENV__.file, __ENV__.line}\n    ) %>\n```","ref":"LiveViewNative.TagEngine.html#component/3"},{"type":"macro","title":"LiveViewNative.TagEngine.inner_block/2","doc":"Define a inner block, generally used by slots.\n\nThis macro is mostly used by custom HTML engines that provide\na `slot` implementation and rarely called directly. The\n`name` must be the assign name the slot/block will be stored\nunder.\n\nIf you're using HEEx templates, you should use its higher\nlevel `<:slot>` notation instead. See `Phoenix.Component`\nfor more information.","ref":"LiveViewNative.TagEngine.html#inner_block/2"},{"type":"module","title":"LiveViewNative.Template","doc":"","ref":"LiveViewNative.Template.html"},{"type":"function","title":"LiveViewNative.Template.attributes_escape/1","doc":"","ref":"LiveViewNative.Template.html#attributes_escape/1"},{"type":"function","title":"LiveViewNative.Template.engines/0","doc":"Return all template engines for registered plugins","ref":"LiveViewNative.Template.html#engines/0"},{"type":"function","title":"LiveViewNative.Template.list_value/2","doc":"","ref":"LiveViewNative.Template.html#list_value/2"},{"type":"function","title":"LiveViewNative.Template.style_value/1","doc":"","ref":"LiveViewNative.Template.html#style_value/1"},{"type":"module","title":"LiveViewNative.Template.Parser","doc":"Floki-compliant parser for LiveView Native template syntax\n\n    iex> \"\"\"\n    ...>  \n    ...>    Hello \n    ...>    world! \n    ...>  \n    ...> \"\"\"\n    ...> |> LiveViewNative.Template.Parser.parse_document()\n    {:ok, [{\"Group\", [], [{\"Text\", [{\"class\", \"bold\"}], [\"Hello\"]}, {\"Text\", [], [\"world!\"]}]}]}\n\nYou can pass this AST into Floki for querying:\n\n    iex> \"\"\"\n    ...>  \n    ...>    Hello \"\n    ...>    world! \n    ...>  \n    ...> \"\"\"\n    ...> |> LiveViewNative.Template.Parser.parse_document!()\n    ...> |> Floki.find(\"Text.bold\")\n    [{\"Text\", [{\"class\", \"bold\"}], [\"Hello\"]}]","ref":"LiveViewNative.Template.Parser.html"},{"type":"module","title":"Floki Integration - LiveViewNative.Template.Parser","doc":"Floki support passing parser in by option, this parser is compliant with that API:\n\n    iex> \"\"\"\n    ...>  \n    ...>    Hello \"\n    ...>    world! \n    ...>  \n    ...> \"\"\"\n    ...> |> Floki.parse_document!(html_parser: LiveViewNative.Template.Parser)\n    ...> |> Floki.find(\"Text.bold\")\n    [{\"Text\", [{\"class\", \"bold\"}], [\"Hello\"]}]\n\nOr you can configure as the default:\n\n```elixir\nconfig :floki, :html_parser, LiveViewNative.Tempalte.Parser\n```","ref":"LiveViewNative.Template.Parser.html#module-floki-integration"},{"type":"function","title":"LiveViewNative.Template.Parser.parse_document/2","doc":"Parses an LVN document from a string.\n\nThis is the main function to get a tree from a LVN string.","ref":"LiveViewNative.Template.Parser.html#parse_document/2"},{"type":"function","title":"Options - LiveViewNative.Template.Parser.parse_document/2","doc":"* `:attributes_as_maps` - Change the behaviour of the parser to return the attributes\n    as maps, instead of a list of `{\"key\", \"value\"}`. Default to `false`.","ref":"LiveViewNative.Template.Parser.html#parse_document/2-options"},{"type":"function","title":"Examples - LiveViewNative.Template.Parser.parse_document/2","doc":"iex> LiveViewNative.Template.Parser.parse_document(\"    Hello  \")\n    {:ok, [{\"Group\", [], [{\"Text\", [], []}, {\"Text\", [], [\"Hello\"]}]}]}\n\n    iex> LiveViewNative.Template.Parser.parse_document(\n    ...>   ~S(    Hello  ),\n    ...>   attributes_as_maps: true\n    ...>)\n    {:ok, [{\"Group\", %{}, [{\"Text\", %{}, []}, {\"Text\", %{\"class\" => \"main\"}, [\"Hello\"]}]}]}","ref":"LiveViewNative.Template.Parser.html#parse_document/2-examples"},{"type":"function","title":"LiveViewNative.Template.Parser.parse_document!/2","doc":"Parses a LVN Document from a string.\n\nSimilar to `parse_document/1`, but raises `LiveViewNative.Template.ParseError` if there was an\nerror parsing the document.","ref":"LiveViewNative.Template.Parser.html#parse_document!/2"},{"type":"function","title":"Example - LiveViewNative.Template.Parser.parse_document!/2","doc":"iex> LiveViewNative.Template.Parser.parse_document!(\"    hello  \")\n    [{\"Group\", [], [{\"Text\", [], []}, {\"Text\", [], [\"hello\"]}]}]","ref":"LiveViewNative.Template.Parser.html#parse_document!/2-example"},{"type":"protocol","title":"LiveViewNative.Template.Safe","doc":"Defines the LVN Template safe protocol.\n\nThis protocol relies on iodata, which provides\nbetter performance when sending or streaming data to the client.","ref":"LiveViewNative.Template.Safe.html"},{"type":"function","title":"LiveViewNative.Template.Safe.to_iodata/1","doc":"","ref":"LiveViewNative.Template.Safe.html#to_iodata/1"},{"type":"type","title":"LiveViewNative.Template.Safe.t/0","doc":"All the types that implement this protocol.","ref":"LiveViewNative.Template.Safe.html#t:t/0"},{"type":"module","title":"LiveViewNativeTest","doc":"Conveniences for testing function components as well as\nLiveViews and LiveComponents.","ref":"LiveViewNativeTest.html"},{"type":"module","title":"Testing function components - LiveViewNativeTest","doc":"There are two mechanisms for testing function components. Imagine the\nfollowing component:\n\n    def greet(assigns) do\n      ~LVN\"\"\"\n       Hello, <%= @name %>! \n      \"\"\"\n    end\n\nYou can test it by using `render_component/3`, passing the function\nreference to the component as first argument:\n\n    import LiveViewNativeTest\n\n    test \"greets\" do\n      assert render_component(&MyComponents.greet/1, name: \"Mary\") ==\n               \" Hello, Mary! \"\n    end\n\nHowever, for complex components, often the simplest way to test them\nis by using the `~LVN` sigil itself:\n\n    import LiveViewNative.Component\n    import LiveViewNativeTest\n\n    test \"greets\" do\n      assigns = %{}\n      assert rendered_to_string(~H\"\"\"\n              \n             \"\"\") ==\n               \" Hello, Mary! \"\n    end\n\nThe difference is that we use `rendered_to_string/1` to convert the rendered\ntemplate to a string for testing.","ref":"LiveViewNativeTest.html#module-testing-function-components"},{"type":"module","title":"LiveView Native paths and params - LiveViewNativeTest","doc":"When calling LiveView Native paths for either dead renders or live renders, the path\nthat you call in a regular `Phoenix.LiveViewTest` is identical to the path you call in a\n`LiveViewNativeTest`. The `_format` and `_interface` params are used to delegate to the proper\nrender components and render functions. The examples throughout this documentation will regularly\nshow the use of those two params when calling either `Phoenix.ConnTest.get/3` or `live/3`","ref":"LiveViewNativeTest.html#module-liveview-native-paths-and-params"},{"type":"module","title":"Testing LiveViewNative.LiveViews and LiveViewNative.LiveComponents - LiveViewNativeTest","doc":"In LiveViewNative.LiveComponents and LiveViewNative.LiveView tests, we interact with views\nvia process communication in substitution of a client.\nLike a client, our test process receives messages about the\nrendered updates from the view which can be asserted against\nto test the life-cycle and behavior of LiveViewNative.LiveViews and their\nchildren.","ref":"LiveViewNativeTest.html#module-testing-liveviewnative-liveviews-and-liveviewnative-livecomponents"},{"type":"module","title":"Testing LiveViewNative.LiveViews - LiveViewNativeTest","doc":"The life-cycle of a LiveViewNative.LiveView as outlined in the `Phoenix.LiveView`\ndocs details how a view starts as a stateless markup render in a disconnected\nsocket state. Once the browser receives the markup, it connects to the\nserver and a new LiveView process is started, remounted in a connected\nsocket state, and the view continues statefully. The LiveView test functions\nsupport testing both disconnected and connected mounts separately, for example:\n\n    import Plug.Conn\n    import Phoenix.ConnTest\n    import LiveViewNativeTest\n    @endpoint MyEndpoint\n\n    test \"disconnected and connected mount\", %{conn: conn} do\n      conn = get(conn, \"/my-path\", _format: \"gameboy\")\n      assert lvn_response(conn, 200, _format: :gameboy) =~ \" My Disconnected View \"\n\n      {:ok, _view, markup} = live(conn, _format: :gameboy)\n      assert markup =~ \" My Connected View \"\n    end\n\n    test \"redirected mount\", %{conn: conn} do\n      assert {:error, {:redirect, %{to: \"/somewhere\"}}} = live(conn, \"my-path\")\n    end\n\nHere, we start by using the familiar `Phoenix.ConnTest` function, `get/3` to\ntest the regular HTTP GET request which invokes mount with a disconnected socket.\nNext, `live/2` is called with our sent connection to mount the view in a connected\nstate, which starts our stateful LiveView process.\n\nIn general, it's often more convenient to test the mounting of a view\nin a single step, provided you don't need the result of the stateless HTTP\nrender. This is done with a single call to `live/3`, which performs the\n`get` step for us:\n\n    test \"connected mount\", %{conn: conn} do\n      {:ok, _view, markup} = live(conn, \"/my-path\", _format: :gameboy)\n      assert markup =~ \" My Connected View \"\n    end","ref":"LiveViewNativeTest.html#module-testing-liveviewnative-liveviews"},{"type":"module","title":"Testing Events - LiveViewNativeTest","doc":"The client can send a variety of events to a LiveView via `phx-` bindings,\nwhich are sent to the `handle_event/3` callback. To test events sent by the\nbrowser and assert on the rendered side effect of the event, use the\n`render_*` functions:\n\n  * `render_click/1` - sends a phx-click event and value, returning\n    the rendered result of the `handle_event/3` callback.\n\n  * `render_focus/2` - sends a phx-focus event and value, returning\n    the rendered result of the `handle_event/3` callback.\n\n  * `render_blur/1` - sends a phx-blur event and value, returning\n    the rendered result of the `handle_event/3` callback.\n\n  * `render_submit/1` - sends a form phx-submit event and value, returning\n    the rendered result of the `handle_event/3` callback.\n\n  * `render_change/1` - sends a form phx-change event and value, returning\n    the rendered result of the `handle_event/3` callback.\n\n  * `render_keydown/1` - sends a form phx-keydown event and value, returning\n    the rendered result of the `handle_event/3` callback.\n\n  * `render_keyup/1` - sends a form phx-keyup event and value, returning\n    the rendered result of the `handle_event/3` callback.\n\n  * `render_hook/3` - sends a hook event and value, returning\n    the rendered result of the `handle_event/3` callback.\n\nFor example:\n\n    {:ok, view, _markup} = live(conn, \"/thermo\", _format: :gameboy)\n\n    assert view\n           |> element(\"button#inc\")\n           |> render_click() =~ \"The temperature is: 31℉\"\n\nIn the example above, we are looking for a particular element on the page\nand triggering its phx-click event. LiveView takes care of making sure the\nelement has a phx-click and automatically sends its values to the server.\n\nYou can also bypass the element lookup and directly trigger the LiveView\nevent in most functions:\n\n    assert render_click(view, :inc, %{}) =~ \"The temperature is: 31℉\"\n\nThe `element` style is preferred as much as possible, as it helps LiveView\nperform validations and ensure the events in the markup actually matches the\nevent names on the server.","ref":"LiveViewNativeTest.html#module-testing-events"},{"type":"module","title":"Testing regular messages - LiveViewNativeTest","doc":"LiveViews are `GenServer`'s under the hood, and can send and receive messages\njust like any other server. To test the side effects of sending or receiving\nmessages, simply message the view and use the `render` function to test the\nresult:\n\n    send(view.pid, {:set_temp, 50})\n    assert render(view) =~ \"The temperature is: 50℉\"","ref":"LiveViewNativeTest.html#module-testing-regular-messages"},{"type":"module","title":"Testing LiveViewNative.LiveComponents - LiveViewNativeTest","doc":"LiveViewNative.LiveComponents can be tested in two ways. One way is to use the same\n`render_component/2` function as function components. This will mount\nthe LiveComponent and render it once, without testing any of its events:\n\n    assert render_component(MyComponent, id: 123, user: %User{}) =~\n             \"some markup in component\"\n\nHowever, if you want to test how components are mounted by a LiveView\nand interact with ViewTree events, you must use the regular `live/3` macro\nto build the LiveView with the component and then scope events by\npassing the view and a **ViewTree selector** in a list:\n\n    {:ok, view, _markup} = live(conn, \"/users\", _format: :gameboy)\n    markup = view |> element(\"#user-13 a\", \"Delete\") |> render_click()\n    refute markup =~ \"user-13\"\n    refute view |> element(\"#user-13\") |> has_element?()\n\nIn the example above, LiveView will lookup for an element with\nID=user-13 and retrieve its `phx-target`. If `phx-target` points\nto a component, that will be the component used, otherwise it will\nfallback to the view.","ref":"LiveViewNativeTest.html#module-testing-liveviewnative-livecomponents"},{"type":"function","title":"LiveViewNativeTest.assert_patch/2","doc":"Asserts a live patch will happen within `timeout` milliseconds.\nThe default `timeout` is [ExUnit](https://hexdocs.pm/ex_unit/ExUnit.html#configure/1)'s\n`assert_receive_timeout` (100 ms).\n\nIt returns the new path.\n\nTo assert on the flash message, you can assert on the result of the\nrendered LiveView.","ref":"LiveViewNativeTest.html#assert_patch/2"},{"type":"function","title":"Examples - LiveViewNativeTest.assert_patch/2","doc":"render_click(view, :event_that_triggers_patch)\n    assert_patch view\n\n    render_click(view, :event_that_triggers_patch)\n    assert_patch view, 30\n\n    render_click(view, :event_that_triggers_patch)\n    path = assert_patch view\n    assert path =~ ~r/path/+/","ref":"LiveViewNativeTest.html#assert_patch/2-examples"},{"type":"function","title":"LiveViewNativeTest.assert_patch/3","doc":"Asserts a live patch will happen to a given path within `timeout`\nmilliseconds.\n\nThe default `timeout` is [ExUnit](https://hexdocs.pm/ex_unit/ExUnit.html#configure/1)'s\n`assert_receive_timeout` (100 ms).\n\nIt returns the new path.\n\nTo assert on the flash message, you can assert on the result of the\nrendered LiveView.","ref":"LiveViewNativeTest.html#assert_patch/3"},{"type":"function","title":"Examples - LiveViewNativeTest.assert_patch/3","doc":"render_click(view, :event_that_triggers_patch)\n    assert_patch view, \"/path\"\n\n    render_click(view, :event_that_triggers_patch)\n    assert_patch view, \"/path\", 30","ref":"LiveViewNativeTest.html#assert_patch/3-examples"},{"type":"function","title":"LiveViewNativeTest.assert_patched/2","doc":"Asserts a live patch was performed, and returns the new path.\n\nTo assert on the flash message, you can assert on the result of\nthe rendered LiveView.","ref":"LiveViewNativeTest.html#assert_patched/2"},{"type":"function","title":"Examples - LiveViewNativeTest.assert_patched/2","doc":"render_click(view, :event_that_triggers_redirect)\n    assert_patched view, \"/path\"","ref":"LiveViewNativeTest.html#assert_patched/2-examples"},{"type":"macro","title":"LiveViewNativeTest.assert_push_event/4","doc":"Asserts an event will be pushed within `timeout`.\nThe default `timeout` is [ExUnit](https://hexdocs.pm/ex_unit/ExUnit.html#configure/1)'s\n`assert_receive_timeout` (100 ms).","ref":"LiveViewNativeTest.html#assert_push_event/4"},{"type":"macro","title":"Examples - LiveViewNativeTest.assert_push_event/4","doc":"assert_push_event view, \"scores\", %{points: 100, user: \"josé\"}","ref":"LiveViewNativeTest.html#assert_push_event/4-examples"},{"type":"function","title":"LiveViewNativeTest.assert_redirect/2","doc":"Asserts a redirect will happen within `timeout` milliseconds.\nThe default `timeout` is [ExUnit](https://hexdocs.pm/ex_unit/ExUnit.html#configure/1)'s\n`assert_receive_timeout` (100 ms).\n\nIt returns a tuple containing the new path and the flash messages from said\nredirect, if any. Note the flash will contain string keys.","ref":"LiveViewNativeTest.html#assert_redirect/2"},{"type":"function","title":"Examples - LiveViewNativeTest.assert_redirect/2","doc":"render_click(view, :event_that_triggers_redirect)\n    {path, flash} = assert_redirect view\n    assert flash[\"info\"] == \"Welcome\"\n    assert path =~ ~r/path\\/\\d+/\n\n    render_click(view, :event_that_triggers_redirect)\n    assert_redirect view, 30","ref":"LiveViewNativeTest.html#assert_redirect/2-examples"},{"type":"function","title":"LiveViewNativeTest.assert_redirect/3","doc":"Asserts a redirect will happen to a given path within `timeout` milliseconds.\n\nThe default `timeout` is [ExUnit](https://hexdocs.pm/ex_unit/ExUnit.html#configure/1)'s\n`assert_receive_timeout` (100 ms).\n\nIt returns the flash messages from said redirect, if any.\nNote the flash will contain string keys.","ref":"LiveViewNativeTest.html#assert_redirect/3"},{"type":"function","title":"Examples - LiveViewNativeTest.assert_redirect/3","doc":"render_click(view, :event_that_triggers_redirect)\n    flash = assert_redirect view, \"/path\"\n    assert flash[\"info\"] == \"Welcome\"\n\n    render_click(view, :event_that_triggers_redirect)\n    assert_redirect view, \"/path\", 30","ref":"LiveViewNativeTest.html#assert_redirect/3-examples"},{"type":"function","title":"LiveViewNativeTest.assert_redirected/2","doc":"Asserts a redirect was performed.\n\nIt returns the flash messages from said redirect, if any. Note the\nflash will contain string keys.","ref":"LiveViewNativeTest.html#assert_redirected/2"},{"type":"function","title":"Examples - LiveViewNativeTest.assert_redirected/2","doc":"render_click(view, :event_that_triggers_redirect)\n    flash = assert_redirected view, \"/path\"\n    assert flash[\"info\"] == \"Welcome\"","ref":"LiveViewNativeTest.html#assert_redirected/2-examples"},{"type":"macro","title":"LiveViewNativeTest.assert_reply/3","doc":"Asserts a hook reply was returned from a `handle_event` callback.\n\nThe default `timeout` is [ExUnit](https://hexdocs.pm/ex_unit/ExUnit.html#configure/1)'s\n`assert_receive_timeout` (100 ms).","ref":"LiveViewNativeTest.html#assert_reply/3"},{"type":"macro","title":"Examples - LiveViewNativeTest.assert_reply/3","doc":"assert_reply view, %{result: \"ok\", transaction_id: _}","ref":"LiveViewNativeTest.html#assert_reply/3-examples"},{"type":"function","title":"LiveViewNativeTest.element/3","doc":"Returns an element to scope a function to.\n\nIt expects the current LiveView, a query selector, and a text filter.\n\nAn optional text filter may be given to filter the results by the query\nselector. If the text filter is a string or a regex, it will match any\nelement that contains the string (including as a substring) or matches the\nregex.\n\nSo a link containing the text \"unopened\" will match `element(\"a\", \"opened\")`.\nTo prevent this, a regex could specify that \"opened\" appear without the prefix \"un\".\nFor example, `element(\"a\", ~r{(?<!un)opened})`.\nBut it may be clearer to add an LVN template attribute to make the element easier to\nselect.\n\nAfter the text filter is applied, only one element must remain, otherwise an\nerror is raised.\n\nIf no text filter is given, then the query selector itself must return\na single element.\n\n    assert view\n          |> element(\"#term > :first-child\", \"Increment\")\n          |> render() =~ \"Increment \"\n\nAttribute selectors are also supported, and may be used on special cases\nlike ids which contain periods:\n\n    assert view\n           |> element(~s{[href=\"/foo\"][id=\"foo.bar.baz\"]})\n           |> render() =~ \"Increment \"","ref":"LiveViewNativeTest.html#element/3"},{"type":"macro","title":"LiveViewNativeTest.file_input/4","doc":"Builds a file input for testing uploads within a form.\n\nGiven the form ViewTree selector, the upload name, and a list of maps of client metadata\nfor the upload, the returned file input can be passed to `render_upload/2`.\n\nClient metadata takes the following form:\n\n  * `:last_modified` - the last modified timestamp\n  * `:name` - the name of the file\n  * `:content` - the binary content of the file\n  * `:size` - the byte size of the content\n  * `:type` - the MIME type of the file\n  * `:relative_path` - for simulating webkitdirectory metadata\n  * `:meta` - optional metadata sent by the client","ref":"LiveViewNativeTest.html#file_input/4"},{"type":"macro","title":"Examples - LiveViewNativeTest.file_input/4","doc":"avatar = file_input(lv, \"#my-form-id\", :avatar, [%{\n      last_modified: 1_594_171_879_000,\n      name: \"myfile.jpeg\",\n      content: File.read!(\"myfile.jpg\"),\n      size: 1_396_009,\n      type: \"image/jpeg\"\n    }])\n\n    assert render_upload(avatar, \"myfile.jpeg\") =~ \"100%\"","ref":"LiveViewNativeTest.html#file_input/4-examples"},{"type":"function","title":"LiveViewNativeTest.find_live_child/2","doc":"Gets the nested LiveView child by `child_id` from the `parent` LiveView.","ref":"LiveViewNativeTest.html#find_live_child/2"},{"type":"function","title":"Examples - LiveViewNativeTest.find_live_child/2","doc":"{:ok, view, _body} = live(conn, \"/thermo\", _format: :gameboy)\n    assert clock_view = find_live_child(view, \"clock\")\n    assert render_click(clock_view, :snooze) =~ \"snoozing\"","ref":"LiveViewNativeTest.html#find_live_child/2-examples"},{"type":"macro","title":"LiveViewNativeTest.follow_redirect/3","doc":"Follows the redirect from a `render_*` action or an `{:error, redirect}`\ntuple.\n\nImagine you have a LiveView that redirects on a `render_click`\nevent. You can make sure it immediately redirects after the\n`render_click` action by calling `follow_redirect/3`:\n\n    live_view\n    |> render_click(\"redirect\")\n    |> follow_redirect(conn)\n\nOr in the case of an error tuple:\n\n    assert {:error, {:redirect, %{to: \"/somewhere\"}}} = result = live(conn, \"my-path\")\n    {:ok, view, body} = follow_redirect(result, conn, :gameboy)\n\n`follow_redirect/3` expects a connection as second argument.\nThis is the connection that will be used to perform the underlying\nrequest.\n\nIf the LiveView redirects with a live redirect, this macro returns\n`{:ok, live_view, disconnected_body}` with the content of the new\nLiveView, the same as the `live/3` macro. If the LiveView redirects\nwith a regular redirect, this macro returns `{:ok, conn}` with the\nrendered redirected page. In any other case, this macro raises.\n\nFinally, note that you can optionally assert on the path you are\nbeing redirected to by passing a third argument:\n\n    live_view\n    |> render_click(\"redirect\")\n    |> follow_redirect(conn, \"/redirected/page\")","ref":"LiveViewNativeTest.html#follow_redirect/3"},{"type":"macro","title":"LiveViewNativeTest.follow_trigger_action/2","doc":"Receives a `form_element` and asserts that `phx-trigger-action` has been\nset to true, following up on that request.\n\nImagine you have a LiveView that sends an HTTP form submission. Say that it\nsets the `phx-trigger-action` to true, as a response to a submit event.\nYou can follow the trigger action like this:\n\n    form = form(live_view, selector, %{\"form\" => \"data\"})\n\n    # First we submit the form. Optionally verify that phx-trigger-action\n    # is now part of the form.\n    assert render_submit(form) =~ ~r/phx-trigger-action/\n\n    # Now follow the request made by the form\n    conn = follow_trigger_action(form, conn)\n    assert conn.method == \"POST\"\n    assert conn.params == %{\"form\" => \"data\"}","ref":"LiveViewNativeTest.html#follow_trigger_action/2"},{"type":"function","title":"LiveViewNativeTest.form/3","doc":"Returns a form element to scope a function to.\n\nIt expects the current LiveView, a query selector, and the form data.\nThe query selector must return a single element.\n\nThe form data will be validated directly against the form markup and\nmake sure the data you are changing/submitting actually exists, failing\notherwise.","ref":"LiveViewNativeTest.html#form/3"},{"type":"function","title":"Examples - LiveViewNativeTest.form/3","doc":"assert view\n          |> form(\"#term\", user: %{name: \"hello\"})\n          |> render_submit() =~ \"Name updated\"\n\nThis function is meant to mimic what the user can actually do, so you cannot\n set hidden input values. However, hidden values can be given when calling\n `render_submit/2` or `render_change/2`, see their docs for examples.","ref":"LiveViewNativeTest.html#form/3-examples"},{"type":"function","title":"LiveViewNativeTest.has_element?/1","doc":"Checks if the given element exists on the page.","ref":"LiveViewNativeTest.html#has_element?/1"},{"type":"function","title":"Examples - LiveViewNativeTest.has_element?/1","doc":"assert view |> element(\"#some-element\") |> has_element?()","ref":"LiveViewNativeTest.html#has_element?/1-examples"},{"type":"function","title":"LiveViewNativeTest.has_element?/3","doc":"Checks if the given `selector` with `text_filter` is on `view`.\n\nSee `element/3` for more information.","ref":"LiveViewNativeTest.html#has_element?/3"},{"type":"function","title":"Examples - LiveViewNativeTest.has_element?/3","doc":"assert has_element?(view, \"#some-element\")","ref":"LiveViewNativeTest.html#has_element?/3-examples"},{"type":"macro","title":"LiveViewNativeTest.live/3","doc":"Spawns a connected LiveView process.\n\nIf a `path` is given, then a regular `get(conn, path, params)`\nis done and the page is upgraded to a LiveView. If\nno path is given, it assumes a previously rendered\n`%Plug.Conn{}` is given, which will be converted to\na LiveView immediately.","ref":"LiveViewNativeTest.html#live/3"},{"type":"macro","title":"Examples - LiveViewNativeTest.live/3","doc":"{:ok, view, markup} = live(conn, \"/path\", _fromat: :gameboy)\n    assert view.module == MyLive\n    assert markup =~ \"the count is 3\"\n\n    assert {:error, {:redirect, %{to: \"/somewhere\"}}} = live(conn, \"/path\", _format: :gameboy)","ref":"LiveViewNativeTest.html#live/3-examples"},{"type":"function","title":"LiveViewNativeTest.live_children/1","doc":"Returns the current list of LiveView children for the `parent` LiveView.\n\nChildren are returned in the order they appear in the rendered template body.","ref":"LiveViewNativeTest.html#live_children/1"},{"type":"function","title":"Examples - LiveViewNativeTest.live_children/1","doc":"{:ok, view, _body} = live(conn, \"/thermo\", _format: :gameboy)\n    assert [clock_view] = live_children(view)\n    assert render_click(clock_view, :snooze) =~ \"snoozing\"","ref":"LiveViewNativeTest.html#live_children/1-examples"},{"type":"macro","title":"LiveViewNativeTest.live_isolated/3","doc":"Spawns a connected LiveView process mounted in isolation as the sole rendered element.\n\nUseful for testing LiveViews that are not directly routable, such as those\nbuilt as small components to be re-used in multiple parents. Testing routable\nLiveViews is still recommended whenever possible since features such as\nlive navigation require routable LiveViews.","ref":"LiveViewNativeTest.html#live_isolated/3"},{"type":"macro","title":"Options - LiveViewNativeTest.live_isolated/3","doc":"* `:session` - the session to be given to the LiveView\n  * `:_format` - the format of the client connecting\n  * `:_interface` - a map of interface state values from the client\n\nAll other options are forwarded to the LiveView for rendering. Refer to\n`Phoenix.Component.live_render/3` for a list of supported render\noptions.","ref":"LiveViewNativeTest.html#live_isolated/3-options"},{"type":"macro","title":"Examples - LiveViewNativeTest.live_isolated/3","doc":"{:ok, view, markup} =\n      live_isolated(conn, MyAppWeb.ClockLive, session: %{\"tz\" => \"EST\"})\n\nUse `put_connect_params/2` to put connect params for a call to\n`Phoenix.LiveView.get_connect_params/1` in `c:Phoenix.LiveView.mount/3`:\n\n    {:ok, view, html} =\n      conn\n      |> put_connect_params(%{\"param\" => \"value\"})\n      |> live_isolated(AppWeb.ClockLive, session: %{\"tz\" => \"EST\"}, _format: :gameboy)","ref":"LiveViewNativeTest.html#live_isolated/3-examples"},{"type":"function","title":"LiveViewNativeTest.live_redirect/2","doc":"Performs a live redirect from one LiveView to another.\n\nWhen redirecting between two LiveViews of the same `live_session`,\nmounts the new LiveView and shutsdown the previous one, which\nmimics general browser live navigation behaviour.\n\nWhen attempting to navigate from a LiveView of a different\n`live_session`, an error redirect condition is returned indicating\na failed `push_navigate` from the client.","ref":"LiveViewNativeTest.html#live_redirect/2"},{"type":"function","title":"Examples - LiveViewNativeTest.live_redirect/2","doc":"assert {:ok, page_live, _body} = live(conn, \"/page/1\", _format: :gameboy)\n    assert {:ok, page2_live, _body} = live(conn, \"/page/2\", _format: :gameboy)\n\n    assert {:error, {:redirect, _}} = live_redirect(page2_live, to: \"/admin\")","ref":"LiveViewNativeTest.html#live_redirect/2-examples"},{"type":"function","title":"LiveViewNativeTest.lvn_response/3","doc":"Asserts the given status code, that we have a LiveCiewNative client response and\nreturns the response body if one was set or sent.\n\nThe 3rd argument should correspond with the client's format name.","ref":"LiveViewNativeTest.html#lvn_response/3"},{"type":"function","title":"Examples - LiveViewNativeTest.lvn_response/3","doc":"assert lvn_response(conn, 200, :gameboy) =~ \" \"","ref":"LiveViewNativeTest.html#lvn_response/3-examples"},{"type":"function","title":"LiveViewNativeTest.page_title/1","doc":"Returns the most recent title that was updated via a `page_title` assign.","ref":"LiveViewNativeTest.html#page_title/1"},{"type":"function","title":"Examples - LiveViewNativeTest.page_title/1","doc":"render_click(view, :event_that_triggers_page_title_update)\n    assert page_title(view) =~ \"my title\"","ref":"LiveViewNativeTest.html#page_title/1-examples"},{"type":"function","title":"LiveViewNativeTest.preflight_upload/1","doc":"Performs a preflight upload request.\n\nUseful for testing external uploaders to retrieve the `:external` entry metadata.","ref":"LiveViewNativeTest.html#preflight_upload/1"},{"type":"function","title":"Examples - LiveViewNativeTest.preflight_upload/1","doc":"avatar = file_input(lv, \"#my-form-id\", :avatar, [%{name: ..., ...}, ...])\n    assert {:ok, %{ref: _ref, config: %{chunk_size: _}}} = preflight_upload(avatar)","ref":"LiveViewNativeTest.html#preflight_upload/1-examples"},{"type":"function","title":"LiveViewNativeTest.put_connect_params/2","doc":"Puts connect params to be used on LiveView connections.\n\nSee `Phoenix.LiveView.get_connect_params/1`.","ref":"LiveViewNativeTest.html#put_connect_params/2"},{"type":"function","title":"LiveViewNativeTest.put_submitter/2","doc":"Puts the submitter `element_or_selector` on the given `form` element.\n\nA submitter is an element that initiates the form's submit event on the client. When a submitter\nis put on an element created with `form/3` and then the form is submitted via `render_submit/2`,\nthe name/value pair of the submitter will be included in the submit event payload.\n\nThe given element or selector must exist within the form and match one of the following:\n\n- A `button` or `input` element with `type=\"submit\"`.\n\n- A `button` element without a `type` attribute.","ref":"LiveViewNativeTest.html#put_submitter/2"},{"type":"function","title":"Examples - LiveViewNativeTest.put_submitter/2","doc":"form = view |> form(\"#my-form\")\n\n    assert form\n           |> put_submitter(\"button[name=example]\")\n           |> render_submit() =~ \"Submitted example\"","ref":"LiveViewNativeTest.html#put_submitter/2-examples"},{"type":"macro","title":"LiveViewNativeTest.refute_push_event/4","doc":"Refutes an event will be pushed within timeout.\n\nThe default `timeout` is [ExUnit](https://hexdocs.pm/ex_unit/ExUnit.html#configure/1)'s\n`refute_receive_timeout` (100 ms).","ref":"LiveViewNativeTest.html#refute_push_event/4"},{"type":"macro","title":"Examples - LiveViewNativeTest.refute_push_event/4","doc":"refute_push_event view, \"scores\", %{points: _, user: \"josé\"}","ref":"LiveViewNativeTest.html#refute_push_event/4-examples"},{"type":"function","title":"LiveViewNativeTest.refute_redirected/2","doc":"Refutes a redirect to a given path was performed.\n\nIt returns :ok if the specified redirect isn't already in the mailbox.","ref":"LiveViewNativeTest.html#refute_redirected/2"},{"type":"function","title":"Examples - LiveViewNativeTest.refute_redirected/2","doc":"render_click(view, :event_that_triggers_redirect_to_path)\n    :ok = refute_redirected view, \"/wrong_path\"","ref":"LiveViewNativeTest.html#refute_redirected/2-examples"},{"type":"function","title":"LiveViewNativeTest.render/1","doc":"Returns the string template body of the rendered view or element.\n\nIf a view is provided, the entire LiveView is rendered.\nIf a view after calling `with_target/2` or an element\nare given, only that particular context is returned.","ref":"LiveViewNativeTest.html#render/1"},{"type":"function","title":"Examples - LiveViewNativeTest.render/1","doc":"{:ok, view, _body} = live(conn, \"/thermo\", _format: :gameboy)\n    assert render(view) =~ ~s| Snooze |\n\n    assert view\n           |> element(\"#alarm\")\n           |> render() == \"Snooze\"","ref":"LiveViewNativeTest.html#render/1-examples"},{"type":"function","title":"LiveViewNativeTest.render_async/2","doc":"Awaits all current `assign_async` and `start_async` for a given LiveView or element.\n\nIt renders the LiveView or Element once complete and returns the result.\nThe default `timeout` is [ExUnit](https://hexdocs.pm/ex_unit/ExUnit.html#configure/1)'s\n`assert_receive_timeout` (100 ms).","ref":"LiveViewNativeTest.html#render_async/2"},{"type":"function","title":"Examples - LiveViewNativeTest.render_async/2","doc":"{:ok, lv, body} = live(conn, \"/path\", _format: :gameboy)\n    assert body =~ \"loading data...\"\n    assert render_async(lv) =~ \"data loaded!\"","ref":"LiveViewNativeTest.html#render_async/2-examples"},{"type":"function","title":"LiveViewNativeTest.render_blur/2","doc":"Sends a blur event given by `element` and returns the rendered result.\n\nThe `element` is created with `element/3` and must point to a single\nelement on the page with a `phx-blur` attribute in it. The event name\ngiven set on `phx-blur` is then sent to the appropriate LiveView\n(or component if `phx-target` is set accordingly). All `phx-value-*`\nentries in the element are sent as values. Extra values can be given\nwith the `value` argument.\n\nIt returns the contents of the whole LiveView or an `{:error, redirect}`\ntuple.","ref":"LiveViewNativeTest.html#render_blur/2"},{"type":"function","title":"Examples - LiveViewNativeTest.render_blur/2","doc":"{:ok, view, body} = live(conn, \"/thermo\", _format: :gameboy)\n\n    assert view\n           |> element(\"#inactive\")\n           |> render_blur() =~ \"Tap to wake\"","ref":"LiveViewNativeTest.html#render_blur/2-examples"},{"type":"function","title":"LiveViewNativeTest.render_blur/3","doc":"Sends a blur event to the view and returns the rendered result.\n\nIt returns the contents of the whole LiveView or an `{:error, redirect}`\ntuple.","ref":"LiveViewNativeTest.html#render_blur/3"},{"type":"function","title":"Examples - LiveViewNativeTest.render_blur/3","doc":"{:ok, view, body} = live(conn, \"/thermo\", _format: :gameboy)\n    assert body =~ \"The temp is: 30℉\"\n    assert render_blur(view, :inactive) =~ \"Tap to wake\"","ref":"LiveViewNativeTest.html#render_blur/3-examples"},{"type":"function","title":"LiveViewNativeTest.render_change/2","doc":"Sends a form change event given by `element` and returns the rendered result.\n\nThe `element` is created with `element/3` and must point to a single\nelement on the page with a `phx-change` attribute in it. The event name\ngiven set on `phx-change` is then sent to the appropriate LiveView\n(or component if `phx-target` is set accordingly). All `phx-value-*`\nentries in the element are sent as values.\n\nIf you need to pass any extra values or metadata, such as the \"_target\"\nparameter, you can do so by giving a map under the `value` argument.\n\nIt returns the contents of the whole LiveView or an `{:error, redirect}`\ntuple.","ref":"LiveViewNativeTest.html#render_change/2"},{"type":"function","title":"Examples - LiveViewNativeTest.render_change/2","doc":"{:ok, view, body} = live(conn, \"/thermo\", _format: :gameboy)\n\n    assert view\n           |> element(\"form\")\n           |> render_change(%{deg: 123}) =~ \"123 exceeds limits\"\n\n    # Passing metadata\n    {:ok, view, body} = live(conn, \"/thermo\", _format: :gameboy)\n\n    assert view\n           |> element(\"form\")\n           |> render_change(%{_target: [\"deg\"], deg: 123}) =~ \"123 exceeds limits\"\n\nAs with `render_submit/2`, hidden input field values can be provided like so:\n\n    refute view\n          |> form(\"#term\", user: %{name: \"hello\"})\n          |> render_change(%{user: %{\"hidden_field\" => \"example\"}}) =~ \"can't be blank\"","ref":"LiveViewNativeTest.html#render_change/2-examples"},{"type":"function","title":"LiveViewNativeTest.render_change/3","doc":"Sends a form change event to the view and returns the rendered result.\n\nIt returns the contents of the whole LiveView or an `{:error, redirect}`\ntuple.","ref":"LiveViewNativeTest.html#render_change/3"},{"type":"function","title":"Examples - LiveViewNativeTest.render_change/3","doc":"{:ok, view, body} = live(conn, \"/thermo\", _format: :gameboy)\n    assert body =~ \"The temp is: 30℉\"\n    assert render_change(view, :validate, %{deg: 123}) =~ \"123 exceeds limits\"","ref":"LiveViewNativeTest.html#render_change/3-examples"},{"type":"function","title":"LiveViewNativeTest.render_click/2","doc":"Sends a click event given by `element` and returns the rendered result.\n\nThe `element` is created with `element/3` and must point to a single\nelement on the page with a `phx-click` attribute in it. The event name\ngiven set on `phx-click` is then sent to the appropriate LiveView\n(or component if `phx-target` is set accordingly). All `phx-value-*`\nentries in the element are sent as values. Extra values can be given\nwith the `value` argument.\n\nIf the element does not have a `phx-click` attribute but it is\na link (the ` ` tag), the link will be followed accordingly:\n\n  * if the link is a `patch`, the current view will be patched\n  * if the link is a `navigate`, this function will return\n    `{:error, {:live_redirect, %{to: url}}}`, which can be followed\n    with `follow_redirect/2`\n  * if the link is a regular link, this function will return\n    `{:error, {:redirect, %{to: url}}}`, which can be followed\n    with `follow_redirect/2`\n\nIt returns the contents of the whole LiveView or an `{:error, redirect}`\ntuple.","ref":"LiveViewNativeTest.html#render_click/2"},{"type":"function","title":"Examples - LiveViewNativeTest.render_click/2","doc":"{:ok, view, body} = live(conn, \"/thermo\", _format: :gameboy)\n\n    assert view\n           |> element(\"button\", \"Increment\")\n           |> render_click() =~ \"The temperature is: 30℉\"","ref":"LiveViewNativeTest.html#render_click/2-examples"},{"type":"function","title":"LiveViewNativeTest.render_click/3","doc":"Sends a click `event` to the `view` with `value` and returns the rendered result.\n\nIt returns the contents of the whole LiveView or an `{:error, redirect}`\ntuple.","ref":"LiveViewNativeTest.html#render_click/3"},{"type":"function","title":"Examples - LiveViewNativeTest.render_click/3","doc":"{:ok, view, body} = live(conn, \"/thermo\", _format: :gameboy)\n    assert body =~ \"The temperature is: 30℉\"\n    assert render_click(view, :inc) =~ \"The temperature is: 31℉\"","ref":"LiveViewNativeTest.html#render_click/3-examples"},{"type":"macro","title":"LiveViewNativeTest.render_component/3","doc":"Renders a component.\n\nThe first argument may either be a function component, as an\nanonymous function:\n\n    assert render_component(&Weather.city/1, name: \"Kraków\") =~\n             \"some markup in component\"\n\nOr a stateful component as a module. In this case, this function\nwill mount, update, and render the component. The `:id` option is\na required argument:\n\n    assert render_component(MyComponent, id: 123, user: %User{}) =~\n             \"some markup in component\"\n\nIf your component is using the router, you can pass it as argument:\n\n    assert render_component(MyComponent, %{id: 123, user: %User{}}, router: SomeRouter) =~\n             \"some markup in component\"","ref":"LiveViewNativeTest.html#render_component/3"},{"type":"function","title":"LiveViewNativeTest.render_focus/2","doc":"Sends a focus event given by `element` and returns the rendered result.\n\nThe `element` is created with `element/3` and must point to a single\nelement on the page with a `phx-focus` attribute in it. The event name\ngiven set on `phx-focus` is then sent to the appropriate LiveView\n(or component if `phx-target` is set accordingly). All `phx-value-*`\nentries in the element are sent as values. Extra values can be given\nwith the `value` argument.\n\nIt returns the contents of the whole LiveView or an `{:error, redirect}`\ntuple.","ref":"LiveViewNativeTest.html#render_focus/2"},{"type":"function","title":"Examples - LiveViewNativeTest.render_focus/2","doc":"{:ok, view, body} = live(conn, \"/thermo\", _format: :gameboy)\n\n    assert view\n           |> element(\"#inactive\")\n           |> render_focus() =~ \"Tap to wake\"","ref":"LiveViewNativeTest.html#render_focus/2-examples"},{"type":"function","title":"LiveViewNativeTest.render_focus/3","doc":"Sends a focus event to the view and returns the rendered result.\n\nIt returns the contents of the whole LiveView or an `{:error, redirect}`\ntuple.","ref":"LiveViewNativeTest.html#render_focus/3"},{"type":"function","title":"Examples - LiveViewNativeTest.render_focus/3","doc":"{:ok, view, body} = live(conn, \"/thermo\", _format: :gameboy)\n    assert body =~ \"The temp is: 30℉\"\n    assert render_focus(view, :inactive) =~ \"Tap to wake\"","ref":"LiveViewNativeTest.html#render_focus/3-examples"},{"type":"function","title":"LiveViewNativeTest.render_hook/3","doc":"Sends a hook event to the view or an element and returns the rendered result.\n\nIt returns the contents of the whole LiveView or an `{:error, redirect}`\ntuple.","ref":"LiveViewNativeTest.html#render_hook/3"},{"type":"function","title":"Examples - LiveViewNativeTest.render_hook/3","doc":"{:ok, view, body} = live(conn, \"/thermo\", _format: :gameboy)\n    assert body =~ \"The temp is: 30℉\"\n    assert render_hook(view, :refresh, %{deg: 32}) =~ \"The temp is: 32℉\"\n\nIf you are pushing events from a hook to a component, then you must pass\nan `element`, created with `element/3`, as first argument and it must point\nto a single element on the page with a `phx-target` attribute in it:\n\n    {:ok, view, _body} = live(conn, \"/thermo\", _format, :gameboy)\n    assert view\n           |> element(\"#thermo-component\")\n           |> render_hook(:refresh, %{deg: 32}) =~ \"The temp is: 32℉\"","ref":"LiveViewNativeTest.html#render_hook/3-examples"},{"type":"function","title":"LiveViewNativeTest.render_keydown/2","doc":"Sends a keydown event given by `element` and returns the rendered result.\n\nThe `element` is created with `element/3` and must point to a single element\non the page with a `phx-keydown` or `phx-window-keydown` attribute in it.\nThe event name given set on `phx-keydown` is then sent to the appropriate\nLiveView (or component if `phx-target` is set accordingly). All `phx-value-*`\nentries in the element are sent as values. Extra values can be given with\nthe `value` argument.\n\nIt returns the contents of the whole LiveView or an `{:error, redirect}`\ntuple.","ref":"LiveViewNativeTest.html#render_keydown/2"},{"type":"function","title":"Examples - LiveViewNativeTest.render_keydown/2","doc":"{:ok, view, body} = live(conn, \"/thermo\", _format: :gameboy)\n    assert body =~ \"The temp is: 30℉\"\n    assert view |> element(\"#inc\") |> render_keydown() =~ \"The temp is: 31℉\"","ref":"LiveViewNativeTest.html#render_keydown/2-examples"},{"type":"function","title":"LiveViewNativeTest.render_keydown/3","doc":"Sends a keydown event to the view and returns the rendered result.\n\nIt returns the contents of the whole LiveView or an `{:error, redirect}`\ntuple.","ref":"LiveViewNativeTest.html#render_keydown/3"},{"type":"function","title":"Examples - LiveViewNativeTest.render_keydown/3","doc":"{:ok, view, body} = live(conn, \"/thermo\", _format: :gameboy)\n    assert body =~ \"The temp is: 30℉\"\n    assert render_keydown(view, :inc) =~ \"The temp is: 31℉\"","ref":"LiveViewNativeTest.html#render_keydown/3-examples"},{"type":"function","title":"LiveViewNativeTest.render_keyup/2","doc":"Sends a keyup event given by `element` and returns the rendered result.\n\nThe `element` is created with `element/3` and must point to a single\nelement on the page with a `phx-keyup` or `phx-window-keyup` attribute\nin it. The event name given set on `phx-keyup` is then sent to the\nappropriate LiveView (or component if `phx-target` is set accordingly).\nAll `phx-value-*` entries in the element are sent as values. Extra values\ncan be given with the `value` argument.\n\nIt returns the contents of the whole LiveView or an `{:error, redirect}`\ntuple.","ref":"LiveViewNativeTest.html#render_keyup/2"},{"type":"function","title":"Examples - LiveViewNativeTest.render_keyup/2","doc":"{:ok, view, body} = live(conn, \"/thermo\", _format: :gameboy)\n    assert body =~ \"The temp is: 30℉\"\n    assert view |> element(\"#inc\") |> render_keyup() =~ \"The temp is: 31℉\"","ref":"LiveViewNativeTest.html#render_keyup/2-examples"},{"type":"function","title":"LiveViewNativeTest.render_keyup/3","doc":"Sends a keyup event to the view and returns the rendered result.\n\nIt returns the contents of the whole LiveView or an `{:error, redirect}`\ntuple.","ref":"LiveViewNativeTest.html#render_keyup/3"},{"type":"function","title":"Examples - LiveViewNativeTest.render_keyup/3","doc":"{:ok, view, body} = live(conn, \"/thermo\", _format: :gameboy)\n    assert body =~ \"The temp is: 30℉\"\n    assert render_keyup(view, :inc) =~ \"The temp is: 31℉\"","ref":"LiveViewNativeTest.html#render_keyup/3-examples"},{"type":"function","title":"LiveViewNativeTest.render_patch/2","doc":"Simulates a `push_patch` to the given `path` and returns the rendered result.","ref":"LiveViewNativeTest.html#render_patch/2"},{"type":"function","title":"LiveViewNativeTest.render_submit/2","doc":"Sends a form submit event given by `element` and returns the rendered result.\n\nThe `element` is created with `element/3` and must point to a single\nelement on the page with a `phx-submit` attribute in it. The event name\ngiven set on `phx-submit` is then sent to the appropriate LiveView\n(or component if `phx-target` is set accordingly). All `phx-value-*`\nentries in the element are sent as values. Extra values, including hidden\ninput fields, can be given with the `value` argument.\n\nIt returns the contents of the whole LiveView or an `{:error, redirect}`\ntuple.","ref":"LiveViewNativeTest.html#render_submit/2"},{"type":"function","title":"Examples - LiveViewNativeTest.render_submit/2","doc":"{:ok, view, body} = live(conn, \"/thermo\", _format: :gameboy)\n\n    assert view\n           |> element(\"form\")\n           |> render_submit(%{deg: 123, avatar: upload}) =~ \"123 exceeds limits\"\n\nTo submit a form along with some with hidden input values:\n\n    assert view\n           |> form(\"#term\", user: %{name: \"hello\"})\n           |> render_submit(%{user: %{\"hidden_field\" => \"example\"}}) =~ \"Name updated\"\n\nTo submit a form by a specific submit element via `put_submitter/2`:\n\n    assert view\n           |> form(\"#term\", user: %{name: \"hello\"})\n           |> put_submitter(\"button[name=example_action]\")\n           |> render_submit() =~ \"Action taken\"","ref":"LiveViewNativeTest.html#render_submit/2-examples"},{"type":"function","title":"LiveViewNativeTest.render_submit/3","doc":"Sends a form submit event to the view and returns the rendered result.\n\nIt returns the contents of the whole LiveView or an `{:error, redirect}`\ntuple.","ref":"LiveViewNativeTest.html#render_submit/3"},{"type":"function","title":"Examples - LiveViewNativeTest.render_submit/3","doc":"{:ok, view, body} = live(conn, \"/thermo\", _format: :gameboy)\n    assert body =~ \"The temp is: 30℉\"\n    assert render_submit(view, :refresh, %{deg: 32}) =~ \"The temp is: 32℉\"","ref":"LiveViewNativeTest.html#render_submit/3-examples"},{"type":"function","title":"LiveViewNativeTest.render_upload/3","doc":"Performs an upload of a file input and renders the result.\n\nSee `file_input/4` for details on building a file input.","ref":"LiveViewNativeTest.html#render_upload/3"},{"type":"function","title":"Examples - LiveViewNativeTest.render_upload/3","doc":"Given the following LiveView template:\n\n```heex\n<%= for entry <- @uploads.avatar.entries do %>\n  <%= entry.name %>: <%= entry.progress %>%\n<% end %>\n```\n\nYour test case can assert the uploaded content:\n\n    avatar = file_input(lv, \"#my-form-id\", :avatar, [\n      %{\n        last_modified: 1_594_171_879_000,\n        name: \"myfile.jpeg\",\n        content: File.read!(\"myfile.jpg\"),\n        size: 1_396_009,\n        type: \"image/jpeg\"\n      }\n    ])\n\n    assert render_upload(avatar, \"myfile.jpeg\") =~ \"100%\"\n\nBy default, the entire file is chunked to the server, but an optional\npercentage to chunk can be passed to test chunk-by-chunk uploads:\n\n    assert render_upload(avatar, \"myfile.jpeg\", 49) =~ \"49%\"\n    assert render_upload(avatar, \"myfile.jpeg\", 51) =~ \"100%\"\n\nBefore making assertions about the how the upload is consumed server-side,\nyou will need to call `render_submit/1`.\n\nIn the case where an upload progress callback issues a navigate, patch, or\nredirect, the following will be returned:\n\n  * for a patch, the current view will be patched\n  * for a navigate, this function will return\n    `{:error, {:live_redirect, %{to: url}}}`, which can be followed\n    with `follow_redirect/2`\n  * for a regular redirect, this function will return\n    `{:error, {:redirect, %{to: url}}}`, which can be followed\n    with `follow_redirect/2`","ref":"LiveViewNativeTest.html#render_upload/3-examples"},{"type":"function","title":"LiveViewNativeTest.rendered_to_string/1","doc":"Converts a rendered template to a string.","ref":"LiveViewNativeTest.html#rendered_to_string/1"},{"type":"function","title":"Examples - LiveViewNativeTest.rendered_to_string/1","doc":"import LiveViewNative.Component\n    import LiveViewNativeTest\n\n    test \"greets\" do\n      assigns = %{}\n      assert rendered_to_string(~LVN\"\"\"\n              \n             \"\"\") ==\n               \" Hello, Mary! \"\n    end","ref":"LiveViewNativeTest.html#rendered_to_string/1-examples"},{"type":"macro","title":"LiveViewNativeTest.submit_form/2","doc":"Receives a form element and submits the HTTP request through the plug pipeline.\n\nImagine you have a LiveView that validates form data, but submits the form to\na controller via the normal form `action` attribute. This is especially useful\nin scenarios where the result of a form submit needs to write to the plug session.\n\nYou can follow submit the form with the `%Plug.Conn{}`, like this:\n\n    form = form(live_view, selector, %{\"form\" => \"data\"})\n\n    # Now submit the LiveView form to the plug pipeline\n    conn = submit_form(form, conn)\n    assert conn.method == \"POST\"\n    assert conn.params == %{\"form\" => \"data\"}","ref":"LiveViewNativeTest.html#submit_form/2"},{"type":"function","title":"LiveViewNativeTest.with_target/2","doc":"Sets the target of the view for events.\n\nThis emulates `phx-target` directly in tests, without\nhaving to dispatch the event to a specific element.\nThis can be useful for invoking events to one or\nmultiple components at the same time:\n\n    view\n    |> with_target(\"#user-1,#user-2\")\n    |> render_click(\"Hide\", %{})","ref":"LiveViewNativeTest.html#with_target/2"},{"type":"module","title":"LiveViewNativeTest.Element","doc":"The struct returned by `LiveViewNativeTest.element/3`.\n\nThe following public fields represent the element:\n\n  * `selector` - The query selector\n  * `text_filter` - The text to further filter the element\n\nSee the `LiveViewNativeTest` documentation for usage.","ref":"LiveViewNativeTest.Element.html"},{"type":"module","title":"LiveViewNativeTest.Upload","doc":"The struct returned by `LiveViewNativeTest.file_input/4`.\n\nThe following public fields represent the element:\n\n  * `selector` - The query selector\n  * `entries` - The list of selected file entries\n\nSee the `LiveViewNativeTest` documentation for usage.","ref":"LiveViewNativeTest.Upload.html"},{"type":"module","title":"LiveViewNativeTest.View","doc":"The struct for testing LiveViews.\n\nThe following public fields represent the LiveView:\n\n  * `id` - The ViewTree id of the LiveView\n  * `module` - The module of the running LiveView\n  * `pid` - The Pid of the running LiveView\n  * `endpoint` - The endpoint for the LiveView\n  * `target` - The target to scope events to\n\nSee the `LiveViewNativeTest` documentation for usage.","ref":"LiveViewNativeTest.View.html"},{"type":"module","title":"LiveViewNativeTest.ViewTree","doc":"","ref":"LiveViewNativeTest.ViewTree.html"},{"type":"function","title":"LiveViewNativeTest.ViewTree.all/2","doc":"","ref":"LiveViewNativeTest.ViewTree.html#all/2"},{"type":"function","title":"LiveViewNativeTest.ViewTree.all_attributes/2","doc":"","ref":"LiveViewNativeTest.ViewTree.html#all_attributes/2"},{"type":"function","title":"LiveViewNativeTest.ViewTree.all_values/1","doc":"","ref":"LiveViewNativeTest.ViewTree.html#all_values/1"},{"type":"function","title":"LiveViewNativeTest.ViewTree.attribute/2","doc":"","ref":"LiveViewNativeTest.ViewTree.html#attribute/2"},{"type":"function","title":"LiveViewNativeTest.ViewTree.attrs/1","doc":"","ref":"LiveViewNativeTest.ViewTree.html#attrs/1"},{"type":"function","title":"LiveViewNativeTest.ViewTree.by_id!/2","doc":"","ref":"LiveViewNativeTest.ViewTree.html#by_id!/2"},{"type":"function","title":"LiveViewNativeTest.ViewTree.child_nodes/1","doc":"","ref":"LiveViewNativeTest.ViewTree.html#child_nodes/1"},{"type":"function","title":"LiveViewNativeTest.ViewTree.component_id/1","doc":"","ref":"LiveViewNativeTest.ViewTree.html#component_id/1"},{"type":"function","title":"LiveViewNativeTest.ViewTree.component_ids/2","doc":"","ref":"LiveViewNativeTest.ViewTree.html#component_ids/2"},{"type":"function","title":"LiveViewNativeTest.ViewTree.deep_merge/2","doc":"Deep merges two maps.","ref":"LiveViewNativeTest.ViewTree.html#deep_merge/2"},{"type":"function","title":"LiveViewNativeTest.ViewTree.drop_cids/2","doc":"","ref":"LiveViewNativeTest.ViewTree.html#drop_cids/2"},{"type":"function","title":"LiveViewNativeTest.ViewTree.ensure_loaded!/0","doc":"","ref":"LiveViewNativeTest.ViewTree.html#ensure_loaded!/0"},{"type":"function","title":"LiveViewNativeTest.ViewTree.extract_streams/2","doc":"","ref":"LiveViewNativeTest.ViewTree.html#extract_streams/2"},{"type":"function","title":"LiveViewNativeTest.ViewTree.filter/2","doc":"Filters nodes according to `fun`.","ref":"LiveViewNativeTest.ViewTree.html#filter/2"},{"type":"function","title":"LiveViewNativeTest.ViewTree.find_live_views/1","doc":"Find live views in the given markup tree.","ref":"LiveViewNativeTest.ViewTree.html#find_live_views/1"},{"type":"function","title":"LiveViewNativeTest.ViewTree.find_static_views/1","doc":"Find static information in the given markup tree.","ref":"LiveViewNativeTest.ViewTree.html#find_static_views/1"},{"type":"function","title":"LiveViewNativeTest.ViewTree.inner_markup!/2","doc":"","ref":"LiveViewNativeTest.ViewTree.html#inner_markup!/2"},{"type":"function","title":"LiveViewNativeTest.ViewTree.inspect_markup/1","doc":"","ref":"LiveViewNativeTest.ViewTree.html#inspect_markup/1"},{"type":"function","title":"LiveViewNativeTest.ViewTree.maybe_one/3","doc":"","ref":"LiveViewNativeTest.ViewTree.html#maybe_one/3"},{"type":"function","title":"LiveViewNativeTest.ViewTree.merge_diff/2","doc":"","ref":"LiveViewNativeTest.ViewTree.html#merge_diff/2"},{"type":"function","title":"LiveViewNativeTest.ViewTree.parent_id/2","doc":"","ref":"LiveViewNativeTest.ViewTree.html#parent_id/2"},{"type":"function","title":"LiveViewNativeTest.ViewTree.parse/1","doc":"","ref":"LiveViewNativeTest.ViewTree.html#parse/1"},{"type":"function","title":"LiveViewNativeTest.ViewTree.parse_sorted!/1","doc":"Parses markup into Floki format with sorted attributes.","ref":"LiveViewNativeTest.ViewTree.html#parse_sorted!/1"},{"type":"function","title":"LiveViewNativeTest.ViewTree.patch_id/4","doc":"","ref":"LiveViewNativeTest.ViewTree.html#patch_id/4"},{"type":"function","title":"LiveViewNativeTest.ViewTree.render_diff/1","doc":"","ref":"LiveViewNativeTest.ViewTree.html#render_diff/1"},{"type":"function","title":"LiveViewNativeTest.ViewTree.replace_root_container/3","doc":"","ref":"LiveViewNativeTest.ViewTree.html#replace_root_container/3"},{"type":"function","title":"LiveViewNativeTest.ViewTree.reverse_filter/2","doc":"Filters nodes and returns them in reverse order.","ref":"LiveViewNativeTest.ViewTree.html#reverse_filter/2"},{"type":"function","title":"LiveViewNativeTest.ViewTree.set_attr/3","doc":"","ref":"LiveViewNativeTest.ViewTree.html#set_attr/3"},{"type":"macro","title":"LiveViewNativeTest.ViewTree.sigil_X/2","doc":"","ref":"LiveViewNativeTest.ViewTree.html#sigil_X/2"},{"type":"macro","title":"LiveViewNativeTest.ViewTree.sigil_x/2","doc":"","ref":"LiveViewNativeTest.ViewTree.html#sigil_x/2"},{"type":"function","title":"LiveViewNativeTest.ViewTree.t2h/1","doc":"","ref":"LiveViewNativeTest.ViewTree.html#t2h/1"},{"type":"function","title":"LiveViewNativeTest.ViewTree.tag/1","doc":"","ref":"LiveViewNativeTest.ViewTree.html#tag/1"},{"type":"function","title":"LiveViewNativeTest.ViewTree.targets_from_node/2","doc":"","ref":"LiveViewNativeTest.ViewTree.html#targets_from_node/2"},{"type":"function","title":"LiveViewNativeTest.ViewTree.targets_from_selector/2","doc":"","ref":"LiveViewNativeTest.ViewTree.html#targets_from_selector/2"},{"type":"function","title":"LiveViewNativeTest.ViewTree.to_markup/1","doc":"","ref":"LiveViewNativeTest.ViewTree.html#to_markup/1"},{"type":"function","title":"LiveViewNativeTest.ViewTree.to_text/1","doc":"","ref":"LiveViewNativeTest.ViewTree.html#to_text/1"},{"type":"module","title":"Mix.LiveViewNative","doc":"","ref":"Mix.LiveViewNative.html"},{"type":"function","title":"Mix.LiveViewNative.detect_necessary_deps/0","doc":"","ref":"Mix.LiveViewNative.html#detect_necessary_deps/0"},{"type":"function","title":"Mix.LiveViewNative.plugins/0","doc":"","ref":"Mix.LiveViewNative.html#plugins/0"},{"type":"task","title":"mix lvn","doc":"Prints LiveView Native tasks and their information.\n\n    $ mix lvn\n\nTo print the LiveView Native version, pass `-v` or `--version`, for example:\n\n    $ mix lvn --version","ref":"Mix.Tasks.Lvn.html"},{"type":"task","title":"mix lvn.gen","doc":"Generates the Native module\n\n    $ mix lvn.gen\n\nInstructions will be printed for configuring your application. And a\nnew `Native` module will be copied into the `lib/` directory of your application.","ref":"Mix.Tasks.Lvn.Gen.html"},{"type":"task","title":"Options - mix lvn.gen","doc":"* `--no-live-form` - don't include `LiveViewNative.LiveForm` content in the `Native` module\n* `--no-gettext` - don't include Gettext support","ref":"Mix.Tasks.Lvn.Gen.html#module-options"},{"type":"function","title":"Mix.Tasks.Lvn.Gen.gen/1","doc":"","ref":"Mix.Tasks.Lvn.Gen.html#gen/1"},{"type":"task","title":"mix lvn.gen.layout","doc":"Generates a new format specific layout component and templates\n\n    $ mix lvn.gen.layout swiftui","ref":"Mix.Tasks.Lvn.Gen.Layout.html"},{"type":"task","title":"mix lvn.gen.live","doc":"Generates a new format specific LiveView render component and template\n\n    $ mix lvn.gen.live swiftui Home","ref":"Mix.Tasks.Lvn.Gen.Live.html"},{"type":"task","title":"mix lvn.setup","doc":"@{shortdoc}\n\n    $ mix lvn.setup","ref":"Mix.Tasks.Lvn.Setup.html"},{"type":"task","title":"mix lvn.setup.config","doc":"Configure LiveView Native within a Phoenix LiveView application\n\nThis setup will\n\n    $ mix lvn.setup.config","ref":"Mix.Tasks.Lvn.Setup.Config.html"},{"type":"task","title":"mix lvn.setup.gen","doc":"Run LiveView Native setup generators within a Phoenix LiveView application\n\nThis setup will\n\n    $ mix lvn.setup.gen","ref":"Mix.Tasks.Lvn.Setup.Gen.html"},{"type":"task","title":"Options - mix lvn.setup.gen","doc":"* `--no-gettext` - don't include Gettext support","ref":"Mix.Tasks.Lvn.Setup.Gen.html#module-options"},{"type":"function","title":"Mix.Tasks.Lvn.Setup.Gen.generators/1","doc":"","ref":"Mix.Tasks.Lvn.Setup.Gen.html#generators/1"},{"type":"exception","title":"LiveViewNative.PluginError","doc":"","ref":"LiveViewNative.PluginError.html"},{"type":"exception","title":"LiveViewNative.Template.ParseError","doc":"","ref":"LiveViewNative.Template.ParseError.html"},{"type":"extras","title":"LiveViewNative","doc":"# LiveViewNative\n\n[![Build Status](https://github.com/liveview-native/live_view_native/workflows/Elixir%20CI/badge.svg)](https://github.com/liveview-native/live_view_native/actions) [![Hex.pm](https://img.shields.io/hexpm/v/live_view_native.svg)](https://hex.pm/packages/live_view_native) [![Documentation](https://img.shields.io/badge/documentation-gray)](https://hexdocs.pm/live_view_native)","ref":"readme.html"},{"type":"extras","title":"About - LiveViewNative","doc":"LiveView Native is a platform for building native applications using [Elixir](https://elixir-lang.org/) and [Phoenix LiveView](https://github.com/phoenixframework/phoenix_live_view). It allows a single LiveView to serve both web and non-web clients by transforming platform-specific template code into native UIs:\n\n```elixir\n# lib/my_app_web/live/hello_live.ex\ndefmodule MyAppWeb.HelloLive do\n  use MyAppWeb, :live_view\n  use MyAppNative, :live_view\nend\n\n# liv/my_app_web/live/hello_live_swiftui.ex\ndefmodule MyAppWeb.HelloLive.SwiftUI do\n  use MyAppNative, [:render_component, format: :swiftui]\n\n  def render(assigns, %{\"target\" => \"watchos\"}) do\n    ~LVN\"\"\"\n     \n       \n        Hello WatchOS!\n       \n     \n    \"\"\"\n  end\n\n  def render(assigns, _interface) do\n    ~LVN\"\"\"\n     \n       \n        Hello SwiftUI!\n       \n     \n    \"\"\"\n  end\nend\n```","ref":"readme.html#about"},{"type":"extras","title":"Getting started - LiveViewNative","doc":"To get started with LiveView Native, you'll need to have an existing [Phoenix Application](https://hexdocs.pm/phoenix/up_and_running.html) or create a new one.\n\nAdd `live_view_native` to your list of dependencies in the `mix.exs` file. In addition to `live_view_native` you may want to include some additional libraries:\n\n```elixir\n{:live_view_native, \"~> 0.4.0-rc.1\"},\n{:live_view_native_stylesheet, \"~> 0.4.0-rc.1\"},\n{:live_view_native_swiftui, \"~> 0.4.0-rc.1\"},\n{:live_view_native_live_form, \"~> 0.4.0-rc.1\"}\n```\n\nThen run:\n\n```\n$ mix lvn.setup\n```\n\nand follow the instructions on how to complete the setup process.","ref":"readme.html#getting-started"},{"type":"extras","title":"Native Clients - LiveViewNative","doc":"LiveView Native enables client frameworks such as:\n\n| UI Framework     | Devices                                              | LiveView Client |\n|------------------|------------------------------------------------------|-----------------|\n| SwiftUI          | iPhone, iPad, AppleTV, Apple Watch, MacOS, Apple Vision Pro | [LiveView Native SwiftUI](https://github.com/liveview-native/liveview-client-swiftui) |\n| JetPack Compose  | Android family                                       | [LiveView Native Jetpack](https://github.com/liveview-native/liveview-client-jetpack) |\n| HTML             |                                                    | [LiveView Native HTML](https://github.com/liveview-native/liveview-client-html) |","ref":"readme.html#native-clients"},{"type":"extras","title":"Questions? - LiveViewNative","doc":"Have a question or want some help with LiveView Native?\n\nCheck out the `#liveview-native` channel on the [Elixir Lang Slack](https://elixir-lang.slack.com/).","ref":"readme.html#questions"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}